#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

/*
 * Copyright (c) 2018-2019 Robin Jarry
 * SPDX-License-Identifier: MIT
 */

#include <libyang/libyang.h>

#if (LY_VERSION_MAJOR != 1)
#error "This version of libyang bindings only works with libyang 1.x"
#endif
#if (LY_VERSION_MINOR < 8)
#error "Need at least libyang 1.8"
#endif

static LY_ERR lypy_get_errno(void)
{
	return ly_errno;
}

static void lypy_set_errno(LY_ERR err)
{
	ly_errno = err;
}

static uint8_t lypy_module_implemented(const struct lys_module *module)
{
	if (module)
		return module->implemented;
	return 0;
}


/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 187), // LY_ERR()(void)
/*  1 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION, 3), // LY_LOG_LEVEL()(LY_LOG_LEVEL)
/*  3 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // LY_LOG_LEVEL
/*  4 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION, 222), // LY_VECODE()(struct ly_ctx const *)
/*  6 */ _CFFI_OP(_CFFI_OP_POINTER, 231), // struct ly_ctx const *
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION, 223), // char *()(struct lyd_node const *)
/*  9 */ _CFFI_OP(_CFFI_OP_POINTER, 237), // struct lyd_node const *
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION, 223), // char *()(struct lys_node const *)
/* 12 */ _CFFI_OP(_CFFI_OP_POINTER, 253), // struct lys_node const *
/* 13 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION, 223), // char *()(struct lys_node const *, char const *)
/* 15 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 16 */ _CFFI_OP(_CFFI_OP_POINTER, 225), // char const *
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION, 223), // char *()(struct lys_node const *, int)
/* 19 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 20 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION, 228), // double()(struct lyd_node const *)
/* 23 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 25 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(char * *, struct lyd_node const *, LYD_FORMAT, int)
/* 26 */ _CFFI_OP(_CFFI_OP_POINTER, 223), // char * *
/* 27 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 28 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // LYD_FORMAT
/* 29 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 30 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 31 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(char * *, struct lys_module const *, LYS_OUTFORMAT, char const *, int, int)
/* 32 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 33 */ _CFFI_OP(_CFFI_OP_POINTER, 250), // struct lys_module const *
/* 34 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // LYS_OUTFORMAT
/* 35 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 36 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 37 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 38 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(int)
/* 40 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(int, struct lyd_node const *, LYD_FORMAT, int)
/* 43 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 44 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 45 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 46 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(int, struct lys_module const *, LYS_OUTFORMAT, char const *, int, int)
/* 49 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 50 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 51 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 52 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 53 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 54 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 55 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 56 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(struct ly_ctx *, char const *)
/* 57 */ _CFFI_OP(_CFFI_OP_POINTER, 231), // struct ly_ctx *
/* 58 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 59 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(struct lyd_node * *, int, void *)
/* 61 */ _CFFI_OP(_CFFI_OP_POINTER, 66), // struct lyd_node * *
/* 62 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 63 */ _CFFI_OP(_CFFI_OP_POINTER, 287), // void *
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(struct lyd_node *, struct lyd_node const *, int)
/* 66 */ _CFFI_OP(_CFFI_OP_POINTER, 237), // struct lyd_node *
/* 67 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 68 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 69 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 70 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(struct lyd_node const *, int)
/* 71 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 72 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 73 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 74 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // int()(struct lys_module const *, char const *)
/* 75 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 76 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 77 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 78 */ _CFFI_OP(_CFFI_OP_FUNCTION, 57), // struct ly_ctx *()(char const *, int)
/* 79 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 80 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 81 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION, 196), // struct ly_err_item *()(struct ly_ctx const *)
/* 83 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 85 */ _CFFI_OP(_CFFI_OP_FUNCTION, 203), // struct ly_set *()(struct ly_ctx *, char const *)
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 87 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 89 */ _CFFI_OP(_CFFI_OP_FUNCTION, 203), // struct ly_set *()(struct lyd_node const *, char const *)
/* 90 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 91 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 92 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION, 203), // struct ly_set *()(struct lyd_node const *, struct lys_node const *)
/* 94 */ _CFFI_OP(_CFFI_OP_NOOP, 9),
/* 95 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 96 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION, 206), // struct lyd_difflist *()(struct lyd_node *, struct lyd_node *, int)
/* 98 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 99 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 100 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 101 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // struct lyd_node *()(struct ly_ctx *, char const *, LYD_FORMAT, int, ...)
/* 103 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 104 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 105 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 106 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 107 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 1),
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // struct lyd_node *()(struct ly_ctx *, int, LYD_FORMAT, int, ...)
/* 109 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 110 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 111 */ _CFFI_OP(_CFFI_OP_NOOP, 28),
/* 112 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 113 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 1),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // struct lyd_node *()(struct lyd_node *)
/* 115 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 116 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 117 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // struct lyd_node *()(struct lyd_node *, struct ly_ctx const *, char const *, void *, LYD_ANYDATA_VALUETYPE, int)
/* 118 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 119 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 120 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 121 */ _CFFI_OP(_CFFI_OP_NOOP, 63),
/* 122 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // LYD_ANYDATA_VALUETYPE
/* 123 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 124 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // struct lyd_node *()(struct lyd_node *, struct lys_module const *, char const *)
/* 126 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 128 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 130 */ _CFFI_OP(_CFFI_OP_FUNCTION, 66), // struct lyd_node *()(struct lyd_node *, struct lys_module const *, char const *, char const *)
/* 131 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 132 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 133 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 134 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 135 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 136 */ _CFFI_OP(_CFFI_OP_FUNCTION, 249), // struct lys_module *()(struct lyd_node *)
/* 137 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 138 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 139 */ _CFFI_OP(_CFFI_OP_FUNCTION, 249), // struct lys_module *()(struct lys_module const *)
/* 140 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 141 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 142 */ _CFFI_OP(_CFFI_OP_FUNCTION, 249), // struct lys_module *()(struct lys_node const *)
/* 143 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 144 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 145 */ _CFFI_OP(_CFFI_OP_FUNCTION, 33), // struct lys_module const *()(struct ly_ctx *, char const *, LYS_INFORMAT)
/* 146 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 147 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 148 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // LYS_INFORMAT
/* 149 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 150 */ _CFFI_OP(_CFFI_OP_FUNCTION, 33), // struct lys_module const *()(struct ly_ctx *, char const *, char const *)
/* 151 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 152 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 153 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 154 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 155 */ _CFFI_OP(_CFFI_OP_FUNCTION, 33), // struct lys_module const *()(struct ly_ctx *, int, LYS_INFORMAT)
/* 156 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 157 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 158 */ _CFFI_OP(_CFFI_OP_NOOP, 148),
/* 159 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 160 */ _CFFI_OP(_CFFI_OP_FUNCTION, 33), // struct lys_module const *()(struct ly_ctx const *, char const *, char const *, int)
/* 161 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 162 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 163 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 164 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 165 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 166 */ _CFFI_OP(_CFFI_OP_FUNCTION, 33), // struct lys_module const *()(struct ly_ctx const *, uint32_t *)
/* 167 */ _CFFI_OP(_CFFI_OP_NOOP, 6),
/* 168 */ _CFFI_OP(_CFFI_OP_POINTER, 282), // uint32_t *
/* 169 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 170 */ _CFFI_OP(_CFFI_OP_FUNCTION, 252), // struct lys_node *()(struct lys_node const *)
/* 171 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 172 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 173 */ _CFFI_OP(_CFFI_OP_FUNCTION, 12), // struct lys_node const *()(struct lys_node const *, struct lys_node const *, struct lys_module const *, int)
/* 174 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 175 */ _CFFI_OP(_CFFI_OP_NOOP, 12),
/* 176 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 177 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 178 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 179 */ _CFFI_OP(_CFFI_OP_FUNCTION, 259), // struct lys_node_list const *()(struct lys_node_leaf const *, uint8_t *)
/* 180 */ _CFFI_OP(_CFFI_OP_POINTER, 257), // struct lys_node_leaf const *
/* 181 */ _CFFI_OP(_CFFI_OP_POINTER, 283), // uint8_t *
/* 182 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 183 */ _CFFI_OP(_CFFI_OP_FUNCTION, 283), // uint8_t()(struct lys_module const *)
/* 184 */ _CFFI_OP(_CFFI_OP_NOOP, 33),
/* 185 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 186 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(LY_ERR)
/* 187 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // LY_ERR
/* 188 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 189 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(LY_LOG_LEVEL, char const *, char const *)
/* 190 */ _CFFI_OP(_CFFI_OP_NOOP, 3),
/* 191 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 192 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 193 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 194 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(struct ly_ctx *, struct ly_err_item *)
/* 195 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 196 */ _CFFI_OP(_CFFI_OP_POINTER, 232), // struct ly_err_item *
/* 197 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 198 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(struct ly_ctx *, void *)
/* 199 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 200 */ _CFFI_OP(_CFFI_OP_NOOP, 63),
/* 201 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 202 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(struct ly_set *)
/* 203 */ _CFFI_OP(_CFFI_OP_POINTER, 233), // struct ly_set *
/* 204 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 205 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(struct lyd_difflist *)
/* 206 */ _CFFI_OP(_CFFI_OP_POINTER, 234), // struct lyd_difflist *
/* 207 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 208 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(struct lyd_node *)
/* 209 */ _CFFI_OP(_CFFI_OP_NOOP, 66),
/* 210 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 211 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(void *)
/* 212 */ _CFFI_OP(_CFFI_OP_NOOP, 63),
/* 213 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 214 */ _CFFI_OP(_CFFI_OP_FUNCTION, 287), // void()(void(*)(LY_LOG_LEVEL, char const *, char const *), int)
/* 215 */ _CFFI_OP(_CFFI_OP_POINTER, 189), // void(*)(LY_LOG_LEVEL, char const *, char const *)
/* 216 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 217 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 218 */ _CFFI_OP(_CFFI_OP_POINTER, 219), // LYD_DIFFTYPE *
/* 219 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // LYD_DIFFTYPE
/* 220 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // LYS_NODE
/* 221 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // LY_DATA_TYPE
/* 222 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // LY_VECODE
/* 223 */ _CFFI_OP(_CFFI_OP_POINTER, 225), // char *
/* 224 */ _CFFI_OP(_CFFI_OP_POINTER, 16), // char const * *
/* 225 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 226 */ _CFFI_OP(_CFFI_OP_ARRAY, 225), // char[11]
/* 227 */ (_cffi_opcode_t)(11),
/* 228 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/* 229 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 17), // int8_t
/* 230 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // lyd_val
/* 231 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // struct ly_ctx
/* 232 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // struct ly_err_item
/* 233 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // struct ly_set
/* 234 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // struct lyd_difflist
/* 235 */ _CFFI_OP(_CFFI_OP_POINTER, 102), // struct lyd_node *(*)(struct ly_ctx *, char const *, LYD_FORMAT, int, ...)
/* 236 */ _CFFI_OP(_CFFI_OP_POINTER, 108), // struct lyd_node *(*)(struct ly_ctx *, int, LYD_FORMAT, int, ...)
/* 237 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // struct lyd_node
/* 238 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // struct lyd_node_leaf_list
/* 239 */ _CFFI_OP(_CFFI_OP_POINTER, 240), // struct lys_ext *
/* 240 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // struct lys_ext
/* 241 */ _CFFI_OP(_CFFI_OP_POINTER, 242), // struct lys_ext_instance * *
/* 242 */ _CFFI_OP(_CFFI_OP_POINTER, 243), // struct lys_ext_instance *
/* 243 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // struct lys_ext_instance
/* 244 */ _CFFI_OP(_CFFI_OP_POINTER, 245), // struct lys_feature * *
/* 245 */ _CFFI_OP(_CFFI_OP_POINTER, 246), // struct lys_feature *
/* 246 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // struct lys_feature
/* 247 */ _CFFI_OP(_CFFI_OP_POINTER, 248), // struct lys_iffeature *
/* 248 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // struct lys_iffeature
/* 249 */ _CFFI_OP(_CFFI_OP_POINTER, 250), // struct lys_module *
/* 250 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // struct lys_module
/* 251 */ _CFFI_OP(_CFFI_OP_POINTER, 252), // struct lys_node * *
/* 252 */ _CFFI_OP(_CFFI_OP_POINTER, 253), // struct lys_node *
/* 253 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // struct lys_node
/* 254 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // struct lys_node_container
/* 255 */ _CFFI_OP(_CFFI_OP_POINTER, 256), // struct lys_node_leaf * *
/* 256 */ _CFFI_OP(_CFFI_OP_POINTER, 257), // struct lys_node_leaf *
/* 257 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // struct lys_node_leaf
/* 258 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // struct lys_node_leaflist
/* 259 */ _CFFI_OP(_CFFI_OP_POINTER, 260), // struct lys_node_list const *
/* 260 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // struct lys_node_list
/* 261 */ _CFFI_OP(_CFFI_OP_POINTER, 262), // struct lys_restr *
/* 262 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // struct lys_restr
/* 263 */ _CFFI_OP(_CFFI_OP_POINTER, 264), // struct lys_revision *
/* 264 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // struct lys_revision
/* 265 */ _CFFI_OP(_CFFI_OP_POINTER, 266), // struct lys_tpdf *
/* 266 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // struct lys_tpdf
/* 267 */ _CFFI_OP(_CFFI_OP_POINTER, 268), // struct lys_type *
/* 268 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // struct lys_type
/* 269 */ _CFFI_OP(_CFFI_OP_POINTER, 270), // struct lys_type_bit *
/* 270 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 22), // struct lys_type_bit
/* 271 */ _CFFI_OP(_CFFI_OP_POINTER, 272), // struct lys_type_enum *
/* 272 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 23), // struct lys_type_enum
/* 273 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 25), // struct lys_type_info_binary
/* 274 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 26), // struct lys_type_info_bits
/* 275 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 27), // struct lys_type_info_dec64
/* 276 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 28), // struct lys_type_info_enums
/* 277 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 29), // struct lys_type_info_lref
/* 278 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 30), // struct lys_type_info_num
/* 279 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 31), // struct lys_type_info_str
/* 280 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 32), // struct lys_type_info_union
/* 281 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 20), // uint16_t
/* 282 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22), // uint32_t
/* 283 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 18), // uint8_t
/* 284 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // union ly_set_set
/* 285 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 24), // union lys_type_info
/* 286 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 287 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_LYD_DIFF_END(unsigned long long *o)
{
  int n = (LYD_DIFF_END) <= 0;
  *o = (unsigned long long)((LYD_DIFF_END) | 0);  /* check that LYD_DIFF_END is an integer */
  return n;
}

static int _cffi_const_LYD_DIFF_DELETED(unsigned long long *o)
{
  int n = (LYD_DIFF_DELETED) <= 0;
  *o = (unsigned long long)((LYD_DIFF_DELETED) | 0);  /* check that LYD_DIFF_DELETED is an integer */
  return n;
}

static int _cffi_const_LYD_DIFF_CHANGED(unsigned long long *o)
{
  int n = (LYD_DIFF_CHANGED) <= 0;
  *o = (unsigned long long)((LYD_DIFF_CHANGED) | 0);  /* check that LYD_DIFF_CHANGED is an integer */
  return n;
}

static int _cffi_const_LYD_DIFF_MOVEDAFTER1(unsigned long long *o)
{
  int n = (LYD_DIFF_MOVEDAFTER1) <= 0;
  *o = (unsigned long long)((LYD_DIFF_MOVEDAFTER1) | 0);  /* check that LYD_DIFF_MOVEDAFTER1 is an integer */
  return n;
}

static int _cffi_const_LYD_DIFF_CREATED(unsigned long long *o)
{
  int n = (LYD_DIFF_CREATED) <= 0;
  *o = (unsigned long long)((LYD_DIFF_CREATED) | 0);  /* check that LYD_DIFF_CREATED is an integer */
  return n;
}

static int _cffi_const_LYD_DIFF_MOVEDAFTER2(unsigned long long *o)
{
  int n = (LYD_DIFF_MOVEDAFTER2) <= 0;
  *o = (unsigned long long)((LYD_DIFF_MOVEDAFTER2) | 0);  /* check that LYD_DIFF_MOVEDAFTER2 is an integer */
  return n;
}

static int _cffi_const_LYD_XML(unsigned long long *o)
{
  int n = (LYD_XML) <= 0;
  *o = (unsigned long long)((LYD_XML) | 0);  /* check that LYD_XML is an integer */
  return n;
}

static int _cffi_const_LYD_JSON(unsigned long long *o)
{
  int n = (LYD_JSON) <= 0;
  *o = (unsigned long long)((LYD_JSON) | 0);  /* check that LYD_JSON is an integer */
  return n;
}

static int _cffi_const_LYD_LYB(unsigned long long *o)
{
  int n = (LYD_LYB) <= 0;
  *o = (unsigned long long)((LYD_LYB) | 0);  /* check that LYD_LYB is an integer */
  return n;
}

static int _cffi_const_LYS_IN_UNKNOWN(unsigned long long *o)
{
  int n = (LYS_IN_UNKNOWN) <= 0;
  *o = (unsigned long long)((LYS_IN_UNKNOWN) | 0);  /* check that LYS_IN_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_LYS_IN_YANG(unsigned long long *o)
{
  int n = (LYS_IN_YANG) <= 0;
  *o = (unsigned long long)((LYS_IN_YANG) | 0);  /* check that LYS_IN_YANG is an integer */
  return n;
}

static int _cffi_const_LYS_IN_YIN(unsigned long long *o)
{
  int n = (LYS_IN_YIN) <= 0;
  *o = (unsigned long long)((LYS_IN_YIN) | 0);  /* check that LYS_IN_YIN is an integer */
  return n;
}

static int _cffi_const_LYS_OUT_UNKNOWN(unsigned long long *o)
{
  int n = (LYS_OUT_UNKNOWN) <= 0;
  *o = (unsigned long long)((LYS_OUT_UNKNOWN) | 0);  /* check that LYS_OUT_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_LYS_OUT_YANG(unsigned long long *o)
{
  int n = (LYS_OUT_YANG) <= 0;
  *o = (unsigned long long)((LYS_OUT_YANG) | 0);  /* check that LYS_OUT_YANG is an integer */
  return n;
}

static int _cffi_const_LYS_OUT_YIN(unsigned long long *o)
{
  int n = (LYS_OUT_YIN) <= 0;
  *o = (unsigned long long)((LYS_OUT_YIN) | 0);  /* check that LYS_OUT_YIN is an integer */
  return n;
}

static int _cffi_const_LYS_OUT_TREE(unsigned long long *o)
{
  int n = (LYS_OUT_TREE) <= 0;
  *o = (unsigned long long)((LYS_OUT_TREE) | 0);  /* check that LYS_OUT_TREE is an integer */
  return n;
}

static int _cffi_const_LYS_OUT_INFO(unsigned long long *o)
{
  int n = (LYS_OUT_INFO) <= 0;
  *o = (unsigned long long)((LYS_OUT_INFO) | 0);  /* check that LYS_OUT_INFO is an integer */
  return n;
}

static int _cffi_const_LYS_OUT_JSON(unsigned long long *o)
{
  int n = (LYS_OUT_JSON) <= 0;
  *o = (unsigned long long)((LYS_OUT_JSON) | 0);  /* check that LYS_OUT_JSON is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_DER(unsigned long long *o)
{
  int n = (LY_TYPE_DER) <= 0;
  *o = (unsigned long long)((LY_TYPE_DER) | 0);  /* check that LY_TYPE_DER is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_BINARY(unsigned long long *o)
{
  int n = (LY_TYPE_BINARY) <= 0;
  *o = (unsigned long long)((LY_TYPE_BINARY) | 0);  /* check that LY_TYPE_BINARY is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_BITS(unsigned long long *o)
{
  int n = (LY_TYPE_BITS) <= 0;
  *o = (unsigned long long)((LY_TYPE_BITS) | 0);  /* check that LY_TYPE_BITS is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_BOOL(unsigned long long *o)
{
  int n = (LY_TYPE_BOOL) <= 0;
  *o = (unsigned long long)((LY_TYPE_BOOL) | 0);  /* check that LY_TYPE_BOOL is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_DEC64(unsigned long long *o)
{
  int n = (LY_TYPE_DEC64) <= 0;
  *o = (unsigned long long)((LY_TYPE_DEC64) | 0);  /* check that LY_TYPE_DEC64 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_EMPTY(unsigned long long *o)
{
  int n = (LY_TYPE_EMPTY) <= 0;
  *o = (unsigned long long)((LY_TYPE_EMPTY) | 0);  /* check that LY_TYPE_EMPTY is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_ENUM(unsigned long long *o)
{
  int n = (LY_TYPE_ENUM) <= 0;
  *o = (unsigned long long)((LY_TYPE_ENUM) | 0);  /* check that LY_TYPE_ENUM is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_IDENT(unsigned long long *o)
{
  int n = (LY_TYPE_IDENT) <= 0;
  *o = (unsigned long long)((LY_TYPE_IDENT) | 0);  /* check that LY_TYPE_IDENT is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_INST(unsigned long long *o)
{
  int n = (LY_TYPE_INST) <= 0;
  *o = (unsigned long long)((LY_TYPE_INST) | 0);  /* check that LY_TYPE_INST is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_LEAFREF(unsigned long long *o)
{
  int n = (LY_TYPE_LEAFREF) <= 0;
  *o = (unsigned long long)((LY_TYPE_LEAFREF) | 0);  /* check that LY_TYPE_LEAFREF is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_STRING(unsigned long long *o)
{
  int n = (LY_TYPE_STRING) <= 0;
  *o = (unsigned long long)((LY_TYPE_STRING) | 0);  /* check that LY_TYPE_STRING is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_UNION(unsigned long long *o)
{
  int n = (LY_TYPE_UNION) <= 0;
  *o = (unsigned long long)((LY_TYPE_UNION) | 0);  /* check that LY_TYPE_UNION is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_INT8(unsigned long long *o)
{
  int n = (LY_TYPE_INT8) <= 0;
  *o = (unsigned long long)((LY_TYPE_INT8) | 0);  /* check that LY_TYPE_INT8 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_UINT8(unsigned long long *o)
{
  int n = (LY_TYPE_UINT8) <= 0;
  *o = (unsigned long long)((LY_TYPE_UINT8) | 0);  /* check that LY_TYPE_UINT8 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_INT16(unsigned long long *o)
{
  int n = (LY_TYPE_INT16) <= 0;
  *o = (unsigned long long)((LY_TYPE_INT16) | 0);  /* check that LY_TYPE_INT16 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_UINT16(unsigned long long *o)
{
  int n = (LY_TYPE_UINT16) <= 0;
  *o = (unsigned long long)((LY_TYPE_UINT16) | 0);  /* check that LY_TYPE_UINT16 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_INT32(unsigned long long *o)
{
  int n = (LY_TYPE_INT32) <= 0;
  *o = (unsigned long long)((LY_TYPE_INT32) | 0);  /* check that LY_TYPE_INT32 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_UINT32(unsigned long long *o)
{
  int n = (LY_TYPE_UINT32) <= 0;
  *o = (unsigned long long)((LY_TYPE_UINT32) | 0);  /* check that LY_TYPE_UINT32 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_INT64(unsigned long long *o)
{
  int n = (LY_TYPE_INT64) <= 0;
  *o = (unsigned long long)((LY_TYPE_INT64) | 0);  /* check that LY_TYPE_INT64 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_UINT64(unsigned long long *o)
{
  int n = (LY_TYPE_UINT64) <= 0;
  *o = (unsigned long long)((LY_TYPE_UINT64) | 0);  /* check that LY_TYPE_UINT64 is an integer */
  return n;
}

static int _cffi_const_LY_TYPE_UNKNOWN(unsigned long long *o)
{
  int n = (LY_TYPE_UNKNOWN) <= 0;
  *o = (unsigned long long)((LY_TYPE_UNKNOWN) | 0);  /* check that LY_TYPE_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_LY_SUCCESS(unsigned long long *o)
{
  int n = (LY_SUCCESS) <= 0;
  *o = (unsigned long long)((LY_SUCCESS) | 0);  /* check that LY_SUCCESS is an integer */
  return n;
}

static int _cffi_const_LY_LLERR(unsigned long long *o)
{
  int n = (LY_LLERR) <= 0;
  *o = (unsigned long long)((LY_LLERR) | 0);  /* check that LY_LLERR is an integer */
  return n;
}

static int _cffi_const_LY_LLWRN(unsigned long long *o)
{
  int n = (LY_LLWRN) <= 0;
  *o = (unsigned long long)((LY_LLWRN) | 0);  /* check that LY_LLWRN is an integer */
  return n;
}

static int _cffi_const_LY_LLVRB(unsigned long long *o)
{
  int n = (LY_LLVRB) <= 0;
  *o = (unsigned long long)((LY_LLVRB) | 0);  /* check that LY_LLVRB is an integer */
  return n;
}

static int _cffi_const_LY_LLDBG(unsigned long long *o)
{
  int n = (LY_LLDBG) <= 0;
  *o = (unsigned long long)((LY_LLDBG) | 0);  /* check that LY_LLDBG is an integer */
  return n;
}

static int _cffi_const_LYVE_SUCCESS(unsigned long long *o)
{
  int n = (LYVE_SUCCESS) <= 0;
  *o = (unsigned long long)((LYVE_SUCCESS) | 0);  /* check that LYVE_SUCCESS is an integer */
  return n;
}

static int _cffi_const_LYVE_PATH_EXISTS(unsigned long long *o)
{
  int n = (LYVE_PATH_EXISTS) <= 0;
  *o = (unsigned long long)((LYVE_PATH_EXISTS) | 0);  /* check that LYVE_PATH_EXISTS is an integer */
  return n;
}

static int _cffi_const_LYS_UNKNOWN(unsigned long long *o)
{
  int n = (LYS_UNKNOWN) <= 0;
  *o = (unsigned long long)((LYS_UNKNOWN) | 0);  /* check that LYS_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_LYS_CONTAINER(unsigned long long *o)
{
  int n = (LYS_CONTAINER) <= 0;
  *o = (unsigned long long)((LYS_CONTAINER) | 0);  /* check that LYS_CONTAINER is an integer */
  return n;
}

static int _cffi_const_LYS_CHOICE(unsigned long long *o)
{
  int n = (LYS_CHOICE) <= 0;
  *o = (unsigned long long)((LYS_CHOICE) | 0);  /* check that LYS_CHOICE is an integer */
  return n;
}

static int _cffi_const_LYS_LEAF(unsigned long long *o)
{
  int n = (LYS_LEAF) <= 0;
  *o = (unsigned long long)((LYS_LEAF) | 0);  /* check that LYS_LEAF is an integer */
  return n;
}

static int _cffi_const_LYS_LEAFLIST(unsigned long long *o)
{
  int n = (LYS_LEAFLIST) <= 0;
  *o = (unsigned long long)((LYS_LEAFLIST) | 0);  /* check that LYS_LEAFLIST is an integer */
  return n;
}

static int _cffi_const_LYS_LIST(unsigned long long *o)
{
  int n = (LYS_LIST) <= 0;
  *o = (unsigned long long)((LYS_LIST) | 0);  /* check that LYS_LIST is an integer */
  return n;
}

static int _cffi_const_LYS_ANYXML(unsigned long long *o)
{
  int n = (LYS_ANYXML) <= 0;
  *o = (unsigned long long)((LYS_ANYXML) | 0);  /* check that LYS_ANYXML is an integer */
  return n;
}

static int _cffi_const_LYS_CASE(unsigned long long *o)
{
  int n = (LYS_CASE) <= 0;
  *o = (unsigned long long)((LYS_CASE) | 0);  /* check that LYS_CASE is an integer */
  return n;
}

static int _cffi_const_LYS_NOTIF(unsigned long long *o)
{
  int n = (LYS_NOTIF) <= 0;
  *o = (unsigned long long)((LYS_NOTIF) | 0);  /* check that LYS_NOTIF is an integer */
  return n;
}

static int _cffi_const_LYS_RPC(unsigned long long *o)
{
  int n = (LYS_RPC) <= 0;
  *o = (unsigned long long)((LYS_RPC) | 0);  /* check that LYS_RPC is an integer */
  return n;
}

static int _cffi_const_LYS_INPUT(unsigned long long *o)
{
  int n = (LYS_INPUT) <= 0;
  *o = (unsigned long long)((LYS_INPUT) | 0);  /* check that LYS_INPUT is an integer */
  return n;
}

static int _cffi_const_LYS_OUTPUT(unsigned long long *o)
{
  int n = (LYS_OUTPUT) <= 0;
  *o = (unsigned long long)((LYS_OUTPUT) | 0);  /* check that LYS_OUTPUT is an integer */
  return n;
}

static int _cffi_const_LYS_GROUPING(unsigned long long *o)
{
  int n = (LYS_GROUPING) <= 0;
  *o = (unsigned long long)((LYS_GROUPING) | 0);  /* check that LYS_GROUPING is an integer */
  return n;
}

static int _cffi_const_LYS_USES(unsigned long long *o)
{
  int n = (LYS_USES) <= 0;
  *o = (unsigned long long)((LYS_USES) | 0);  /* check that LYS_USES is an integer */
  return n;
}

static int _cffi_const_LYS_AUGMENT(unsigned long long *o)
{
  int n = (LYS_AUGMENT) <= 0;
  *o = (unsigned long long)((LYS_AUGMENT) | 0);  /* check that LYS_AUGMENT is an integer */
  return n;
}

static int _cffi_const_LYS_ACTION(unsigned long long *o)
{
  int n = (LYS_ACTION) <= 0;
  *o = (unsigned long long)((LYS_ACTION) | 0);  /* check that LYS_ACTION is an integer */
  return n;
}

static int _cffi_const_LYS_ANYDATA(unsigned long long *o)
{
  int n = (LYS_ANYDATA) <= 0;
  *o = (unsigned long long)((LYS_ANYDATA) | 0);  /* check that LYS_ANYDATA is an integer */
  return n;
}

static int _cffi_const_LYS_EXT(unsigned long long *o)
{
  int n = (LYS_EXT) <= 0;
  *o = (unsigned long long)((LYS_EXT) | 0);  /* check that LYS_EXT is an integer */
  return n;
}

static struct _cffi_externpy_s _cffi_externpy__lypy_log_cb =
  { "_libyang.lypy_log_cb", 0, 0, 0 };

static void lypy_log_cb(LY_LOG_LEVEL a0, char const * a1, char const * a2)
{
  char a[24];
  char *p = a;
  *(LY_LOG_LEVEL *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  *(char const * *)(p + 16) = a2;
  _cffi_call_python(&_cffi_externpy__lypy_log_cb, p);
}

static void _cffi_d_free(void * x0)
{
  free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_free(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_free _cffi_d_free
#endif

static void _cffi_d_ly_ctx_destroy(struct ly_ctx * x0, void * x1)
{
  ly_ctx_destroy(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_destroy(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_ctx_destroy", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { ly_ctx_destroy(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_ly_ctx_destroy _cffi_d_ly_ctx_destroy
#endif

static struct ly_set * _cffi_d_ly_ctx_find_path(struct ly_ctx * x0, char const * x1)
{
  return ly_ctx_find_path(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_find_path(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct ly_set * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_ctx_find_path", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_ctx_find_path(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(203));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_ctx_find_path _cffi_d_ly_ctx_find_path
#endif

static struct lys_module const * _cffi_d_ly_ctx_get_module(struct ly_ctx const * x0, char const * x1, char const * x2, int x3)
{
  return ly_ctx_get_module(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_get_module(PyObject *self, PyObject *args)
{
  struct ly_ctx const * x0;
  char const * x1;
  char const * x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "ly_ctx_get_module", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(6), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(6), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_ctx_get_module(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(33));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_ctx_get_module _cffi_d_ly_ctx_get_module
#endif

static struct lys_module const * _cffi_d_ly_ctx_get_module_iter(struct ly_ctx const * x0, uint32_t * x1)
{
  return ly_ctx_get_module_iter(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_get_module_iter(PyObject *self, PyObject *args)
{
  struct ly_ctx const * x0;
  uint32_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_ctx_get_module_iter", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(6), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(6), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(168), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (uint32_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(168), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_ctx_get_module_iter(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(33));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_ctx_get_module_iter _cffi_d_ly_ctx_get_module_iter
#endif

static struct lys_module const * _cffi_d_ly_ctx_load_module(struct ly_ctx * x0, char const * x1, char const * x2)
{
  return ly_ctx_load_module(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_load_module(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "ly_ctx_load_module", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_ctx_load_module(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(33));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_ctx_load_module _cffi_d_ly_ctx_load_module
#endif

static struct ly_ctx * _cffi_d_ly_ctx_new(char const * x0, int x1)
{
  return ly_ctx_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_new(PyObject *self, PyObject *args)
{
  char const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct ly_ctx * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_ctx_new", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_ctx_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(57));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_ctx_new _cffi_d_ly_ctx_new
#endif

static int _cffi_d_ly_ctx_set_searchdir(struct ly_ctx * x0, char const * x1)
{
  return ly_ctx_set_searchdir(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_ctx_set_searchdir(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_ctx_set_searchdir", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_ctx_set_searchdir(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_ctx_set_searchdir _cffi_d_ly_ctx_set_searchdir
#endif

static void _cffi_d_ly_err_clean(struct ly_ctx * x0, struct ly_err_item * x1)
{
  ly_err_clean(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_err_clean(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  struct ly_err_item * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_err_clean", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(196), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct ly_err_item *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(196), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { ly_err_clean(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_ly_err_clean _cffi_d_ly_err_clean
#endif

static struct ly_err_item * _cffi_d_ly_err_first(struct ly_ctx const * x0)
{
  return ly_err_first(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_err_first(PyObject *self, PyObject *arg0)
{
  struct ly_ctx const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct ly_err_item * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(6), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(6), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_err_first(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(196));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_err_first _cffi_d_ly_err_first
#endif

static int _cffi_d_ly_log_options(int x0)
{
  return ly_log_options(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_log_options(PyObject *self, PyObject *arg0)
{
  int x0;
  int result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_log_options(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_ly_log_options _cffi_d_ly_log_options
#endif

static void _cffi_d_ly_set_free(struct ly_set * x0)
{
  ly_set_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_set_free(PyObject *self, PyObject *arg0)
{
  struct ly_set * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(203), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_set *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(203), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { ly_set_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_ly_set_free _cffi_d_ly_set_free
#endif

static void _cffi_d_ly_set_log_clb(void(* x0)(LY_LOG_LEVEL, char const *, char const *), int x1)
{
  ly_set_log_clb(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_set_log_clb(PyObject *self, PyObject *args)
{
  void(* x0)(LY_LOG_LEVEL, char const *, char const *);
  int x1;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "ly_set_log_clb", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = (void(*)(LY_LOG_LEVEL, char const *, char const *))_cffi_to_c_pointer(arg0, _cffi_type(215));
  if (x0 == (void(*)(LY_LOG_LEVEL, char const *, char const *))NULL && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { ly_set_log_clb(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_ly_set_log_clb _cffi_d_ly_set_log_clb
#endif

static LY_VECODE _cffi_d_ly_vecode(struct ly_ctx const * x0)
{
  return ly_vecode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_vecode(PyObject *self, PyObject *arg0)
{
  struct ly_ctx const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  LY_VECODE result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(6), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(6), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_vecode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(222));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_ly_vecode _cffi_d_ly_vecode
#endif

static LY_LOG_LEVEL _cffi_d_ly_verb(LY_LOG_LEVEL x0)
{
  return ly_verb(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_ly_verb(PyObject *self, PyObject *arg0)
{
  LY_LOG_LEVEL x0;
  LY_LOG_LEVEL result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(3), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = ly_verb(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(3));
  return pyresult;
}
#else
#  define _cffi_f_ly_verb _cffi_d_ly_verb
#endif

static double _cffi_d_lyd_dec64_to_double(struct lyd_node const * x0)
{
  return lyd_dec64_to_double(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_dec64_to_double(PyObject *self, PyObject *arg0)
{
  struct lyd_node const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_dec64_to_double(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_dec64_to_double _cffi_d_lyd_dec64_to_double
#endif

static struct lyd_difflist * _cffi_d_lyd_diff(struct lyd_node * x0, struct lyd_node * x1, int x2)
{
  return lyd_diff(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_diff(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct lyd_node * x1;
  int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_difflist * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lyd_diff", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_diff(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(206));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_diff _cffi_d_lyd_diff
#endif

static struct ly_set * _cffi_d_lyd_find_instance(struct lyd_node const * x0, struct lys_node const * x1)
{
  return lyd_find_instance(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_find_instance(PyObject *self, PyObject *args)
{
  struct lyd_node const * x0;
  struct lys_node const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct ly_set * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lyd_find_instance", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_find_instance(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(203));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_find_instance _cffi_d_lyd_find_instance
#endif

static struct ly_set * _cffi_d_lyd_find_path(struct lyd_node const * x0, char const * x1)
{
  return lyd_find_path(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_find_path(PyObject *self, PyObject *args)
{
  struct lyd_node const * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct ly_set * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lyd_find_path", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_find_path(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(203));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_find_path _cffi_d_lyd_find_path
#endif

static struct lyd_node * _cffi_d_lyd_first_sibling(struct lyd_node * x0)
{
  return lyd_first_sibling(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_first_sibling(PyObject *self, PyObject *arg0)
{
  struct lyd_node * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_node * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_first_sibling(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_first_sibling _cffi_d_lyd_first_sibling
#endif

static void _cffi_d_lyd_free(struct lyd_node * x0)
{
  lyd_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_free(PyObject *self, PyObject *arg0)
{
  struct lyd_node * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { lyd_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_lyd_free _cffi_d_lyd_free
#endif

static void _cffi_d_lyd_free_diff(struct lyd_difflist * x0)
{
  lyd_free_diff(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_free_diff(PyObject *self, PyObject *arg0)
{
  struct lyd_difflist * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(206), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_difflist *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(206), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { lyd_free_diff(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_lyd_free_diff _cffi_d_lyd_free_diff
#endif

static void _cffi_d_lyd_free_withsiblings(struct lyd_node * x0)
{
  lyd_free_withsiblings(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_free_withsiblings(PyObject *self, PyObject *arg0)
{
  struct lyd_node * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { lyd_free_withsiblings(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_lyd_free_withsiblings _cffi_d_lyd_free_withsiblings
#endif

static int _cffi_d_lyd_merge(struct lyd_node * x0, struct lyd_node const * x1, int x2)
{
  return lyd_merge(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_merge(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct lyd_node const * x1;
  int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lyd_merge", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_merge(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_merge _cffi_d_lyd_merge
#endif

static struct lyd_node * _cffi_d_lyd_new(struct lyd_node * x0, struct lys_module const * x1, char const * x2)
{
  return lyd_new(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_new(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct lys_module const * x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_node * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lyd_new", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_new(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_new _cffi_d_lyd_new
#endif

static struct lyd_node * _cffi_d_lyd_new_leaf(struct lyd_node * x0, struct lys_module const * x1, char const * x2, char const * x3)
{
  return lyd_new_leaf(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_new_leaf(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct lys_module const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_node * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "lyd_new_leaf", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_new_leaf(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_new_leaf _cffi_d_lyd_new_leaf
#endif

static struct lyd_node * _cffi_d_lyd_new_output(struct lyd_node * x0, struct lys_module const * x1, char const * x2)
{
  return lyd_new_output(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_new_output(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct lys_module const * x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_node * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lyd_new_output", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_new_output(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_new_output _cffi_d_lyd_new_output
#endif

static struct lyd_node * _cffi_d_lyd_new_output_leaf(struct lyd_node * x0, struct lys_module const * x1, char const * x2, char const * x3)
{
  return lyd_new_output_leaf(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_new_output_leaf(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct lys_module const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_node * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "lyd_new_output_leaf", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_new_output_leaf(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_new_output_leaf _cffi_d_lyd_new_output_leaf
#endif

static struct lyd_node * _cffi_d_lyd_new_path(struct lyd_node * x0, struct ly_ctx const * x1, char const * x2, void * x3, LYD_ANYDATA_VALUETYPE x4, int x5)
{
  return lyd_new_path(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_new_path(PyObject *self, PyObject *args)
{
  struct lyd_node * x0;
  struct ly_ctx const * x1;
  char const * x2;
  void * x3;
  LYD_ANYDATA_VALUETYPE x4;
  int x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lyd_node * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "lyd_new_path", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(6), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct ly_ctx const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(6), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x4, _cffi_type(122), arg4) < 0)
    return NULL;

  x5 = _cffi_to_c_int(arg5, int);
  if (x5 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_new_path(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(66));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_new_path _cffi_d_lyd_new_path
#endif

static struct lys_module * _cffi_d_lyd_node_module(struct lyd_node * x0)
{
  return lyd_node_module(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_node_module(PyObject *self, PyObject *arg0)
{
  struct lyd_node * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(66), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(66), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_node_module(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(249));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_node_module _cffi_d_lyd_node_module
#endif

static int _cffi_d_lyd_node_should_print(struct lyd_node const * x0, int x1)
{
  return lyd_node_should_print(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_node_should_print(PyObject *self, PyObject *args)
{
  struct lyd_node const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lyd_node_should_print", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_node_should_print(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_node_should_print _cffi_d_lyd_node_should_print
#endif

static void _cffi_const_lyd_parse_fd(char *o)
{
  *(struct lyd_node *(* *)(struct ly_ctx *, int, LYD_FORMAT, int, ...))o = lyd_parse_fd;
}

static void _cffi_const_lyd_parse_mem(char *o)
{
  *(struct lyd_node *(* *)(struct ly_ctx *, char const *, LYD_FORMAT, int, ...))o = lyd_parse_mem;
}

static char * _cffi_d_lyd_path(struct lyd_node const * x0)
{
  return lyd_path(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_path(PyObject *self, PyObject *arg0)
{
  struct lyd_node const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_path(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(223));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_path _cffi_d_lyd_path
#endif

static int _cffi_d_lyd_print_fd(int x0, struct lyd_node const * x1, LYD_FORMAT x2, int x3)
{
  return lyd_print_fd(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_print_fd(PyObject *self, PyObject *args)
{
  int x0;
  struct lyd_node const * x1;
  LYD_FORMAT x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "lyd_print_fd", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(28), arg2) < 0)
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_print_fd(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_print_fd _cffi_d_lyd_print_fd
#endif

static int _cffi_d_lyd_print_mem(char * * x0, struct lyd_node const * x1, LYD_FORMAT x2, int x3)
{
  return lyd_print_mem(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_print_mem(PyObject *self, PyObject *args)
{
  char * * x0;
  struct lyd_node const * x1;
  LYD_FORMAT x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "lyd_print_mem", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(9), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lyd_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(9), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(28), arg2) < 0)
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_print_mem(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_print_mem _cffi_d_lyd_print_mem
#endif

static int _cffi_d_lyd_validate(struct lyd_node * * x0, int x1, void * x2)
{
  return lyd_validate(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lyd_validate(PyObject *self, PyObject *args)
{
  struct lyd_node * * x0;
  int x1;
  void * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lyd_validate", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lyd_node * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(61), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(63), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lyd_validate(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lyd_validate _cffi_d_lyd_validate
#endif

static LY_ERR _cffi_d_lypy_get_errno(void)
{
  return lypy_get_errno();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lypy_get_errno(PyObject *self, PyObject *noarg)
{
  LY_ERR result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lypy_get_errno(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(187));
  return pyresult;
}
#else
#  define _cffi_f_lypy_get_errno _cffi_d_lypy_get_errno
#endif

static uint8_t _cffi_d_lypy_module_implemented(struct lys_module const * x0)
{
  return lypy_module_implemented(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lypy_module_implemented(PyObject *self, PyObject *arg0)
{
  struct lys_module const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint8_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lypy_module_implemented(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint8_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lypy_module_implemented _cffi_d_lypy_module_implemented
#endif

static void _cffi_d_lypy_set_errno(LY_ERR x0)
{
  lypy_set_errno(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lypy_set_errno(PyObject *self, PyObject *arg0)
{
  LY_ERR x0;

  if (_cffi_to_c((char *)&x0, _cffi_type(187), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { lypy_set_errno(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_lypy_set_errno _cffi_d_lypy_set_errno
#endif

static char * _cffi_d_lys_data_path(struct lys_node const * x0)
{
  return lys_data_path(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_data_path(PyObject *self, PyObject *arg0)
{
  struct lys_node const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_data_path(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(223));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_data_path _cffi_d_lys_data_path
#endif

static char * _cffi_d_lys_data_path_pattern(struct lys_node const * x0, char const * x1)
{
  return lys_data_path_pattern(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_data_path_pattern(PyObject *self, PyObject *args)
{
  struct lys_node const * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lys_data_path_pattern", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_data_path_pattern(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(223));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_data_path_pattern _cffi_d_lys_data_path_pattern
#endif

static int _cffi_d_lys_features_disable(struct lys_module const * x0, char const * x1)
{
  return lys_features_disable(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_features_disable(PyObject *self, PyObject *args)
{
  struct lys_module const * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lys_features_disable", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_features_disable(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_features_disable _cffi_d_lys_features_disable
#endif

static int _cffi_d_lys_features_enable(struct lys_module const * x0, char const * x1)
{
  return lys_features_enable(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_features_enable(PyObject *self, PyObject *args)
{
  struct lys_module const * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lys_features_enable", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_features_enable(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_features_enable _cffi_d_lys_features_enable
#endif

static int _cffi_d_lys_features_state(struct lys_module const * x0, char const * x1)
{
  return lys_features_state(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_features_state(PyObject *self, PyObject *args)
{
  struct lys_module const * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lys_features_state", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_features_state(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_features_state _cffi_d_lys_features_state
#endif

static struct lys_node const * _cffi_d_lys_getnext(struct lys_node const * x0, struct lys_node const * x1, struct lys_module const * x2, int x3)
{
  return lys_getnext(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_getnext(PyObject *self, PyObject *args)
{
  struct lys_node const * x0;
  struct lys_node const * x1;
  struct lys_module const * x2;
  int x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_node const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "lys_getnext", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_getnext(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(12));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_getnext _cffi_d_lys_getnext
#endif

static struct lys_node_list const * _cffi_d_lys_is_key(struct lys_node_leaf const * x0, uint8_t * x1)
{
  return lys_is_key(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_is_key(PyObject *self, PyObject *args)
{
  struct lys_node_leaf const * x0;
  uint8_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_node_list const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lys_is_key", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(180), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node_leaf const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(180), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(181), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (uint8_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(181), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_is_key(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(259));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_is_key _cffi_d_lys_is_key
#endif

static struct lys_module * _cffi_d_lys_main_module(struct lys_module const * x0)
{
  return lys_main_module(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_main_module(PyObject *self, PyObject *arg0)
{
  struct lys_module const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_main_module(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(249));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_main_module _cffi_d_lys_main_module
#endif

static struct lys_module * _cffi_d_lys_node_module(struct lys_node const * x0)
{
  return lys_node_module(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_node_module(PyObject *self, PyObject *arg0)
{
  struct lys_node const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_node_module(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(249));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_node_module _cffi_d_lys_node_module
#endif

static struct lys_node * _cffi_d_lys_parent(struct lys_node const * x0)
{
  return lys_parent(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_parent(PyObject *self, PyObject *arg0)
{
  struct lys_node const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_node * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_parent(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(252));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_parent _cffi_d_lys_parent
#endif

static struct lys_module const * _cffi_d_lys_parse_fd(struct ly_ctx * x0, int x1, LYS_INFORMAT x2)
{
  return lys_parse_fd(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_parse_fd(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  int x1;
  LYS_INFORMAT x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lys_parse_fd", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(148), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_parse_fd(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(33));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_parse_fd _cffi_d_lys_parse_fd
#endif

static struct lys_module const * _cffi_d_lys_parse_mem(struct ly_ctx * x0, char const * x1, LYS_INFORMAT x2)
{
  return lys_parse_mem(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_parse_mem(PyObject *self, PyObject *args)
{
  struct ly_ctx * x0;
  char const * x1;
  LYS_INFORMAT x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct lys_module const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "lys_parse_mem", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct ly_ctx *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(57), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(148), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_parse_mem(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(33));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_parse_mem _cffi_d_lys_parse_mem
#endif

static char * _cffi_d_lys_path(struct lys_node const * x0, int x1)
{
  return lys_path(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_path(PyObject *self, PyObject *args)
{
  struct lys_node const * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "lys_path", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(12), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct lys_node const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(12), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_path(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(223));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_path _cffi_d_lys_path
#endif

static int _cffi_d_lys_print_fd(int x0, struct lys_module const * x1, LYS_OUTFORMAT x2, char const * x3, int x4, int x5)
{
  return lys_print_fd(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_print_fd(PyObject *self, PyObject *args)
{
  int x0;
  struct lys_module const * x1;
  LYS_OUTFORMAT x2;
  char const * x3;
  int x4;
  int x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "lys_print_fd", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(34), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, int);
  if (x5 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_print_fd(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_print_fd _cffi_d_lys_print_fd
#endif

static int _cffi_d_lys_print_mem(char * * x0, struct lys_module const * x1, LYS_OUTFORMAT x2, char const * x3, int x4, int x5)
{
  return lys_print_mem(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_lys_print_mem(PyObject *self, PyObject *args)
{
  char * * x0;
  struct lys_module const * x1;
  LYS_OUTFORMAT x2;
  char const * x3;
  int x4;
  int x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "lys_print_mem", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (char * *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(33), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct lys_module const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(33), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(34), arg2) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(16), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x4 = _cffi_to_c_int(arg4, int);
  if (x4 == (int)-1 && PyErr_Occurred())
    return NULL;

  x5 = _cffi_to_c_int(arg5, int);
  if (x5 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = lys_print_mem(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_lys_print_mem _cffi_d_lys_print_mem
#endif

static int _cffi_const_LYD_ANYDATA_CONSTSTRING(unsigned long long *o)
{
  int n = (LYD_ANYDATA_CONSTSTRING) <= 0;
  *o = (unsigned long long)((LYD_ANYDATA_CONSTSTRING) | 0);  /* check that LYD_ANYDATA_CONSTSTRING is an integer */
  return n;
}

static int _cffi_const_LYD_DIFFOPT_NOSIBLINGS(unsigned long long *o)
{
  int n = (LYD_DIFFOPT_NOSIBLINGS) <= 0;
  *o = (unsigned long long)((LYD_DIFFOPT_NOSIBLINGS) | 0);  /* check that LYD_DIFFOPT_NOSIBLINGS is an integer */
  return n;
}

static int _cffi_const_LYD_DIFFOPT_WITHDEFAULTS(unsigned long long *o)
{
  int n = (LYD_DIFFOPT_WITHDEFAULTS) <= 0;
  *o = (unsigned long long)((LYD_DIFFOPT_WITHDEFAULTS) | 0);  /* check that LYD_DIFFOPT_WITHDEFAULTS is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_CONFIG(unsigned long long *o)
{
  int n = (LYD_OPT_CONFIG) <= 0;
  *o = (unsigned long long)((LYD_OPT_CONFIG) | 0);  /* check that LYD_OPT_CONFIG is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_DATA(unsigned long long *o)
{
  int n = (LYD_OPT_DATA) <= 0;
  *o = (unsigned long long)((LYD_OPT_DATA) | 0);  /* check that LYD_OPT_DATA is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_DATA_NO_YANGLIB(unsigned long long *o)
{
  int n = (LYD_OPT_DATA_NO_YANGLIB) <= 0;
  *o = (unsigned long long)((LYD_OPT_DATA_NO_YANGLIB) | 0);  /* check that LYD_OPT_DATA_NO_YANGLIB is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_DESTRUCT(unsigned long long *o)
{
  int n = (LYD_OPT_DESTRUCT) <= 0;
  *o = (unsigned long long)((LYD_OPT_DESTRUCT) | 0);  /* check that LYD_OPT_DESTRUCT is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_EDIT(unsigned long long *o)
{
  int n = (LYD_OPT_EDIT) <= 0;
  *o = (unsigned long long)((LYD_OPT_EDIT) | 0);  /* check that LYD_OPT_EDIT is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_EXPLICIT(unsigned long long *o)
{
  int n = (LYD_OPT_EXPLICIT) <= 0;
  *o = (unsigned long long)((LYD_OPT_EXPLICIT) | 0);  /* check that LYD_OPT_EXPLICIT is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_GET(unsigned long long *o)
{
  int n = (LYD_OPT_GET) <= 0;
  *o = (unsigned long long)((LYD_OPT_GET) | 0);  /* check that LYD_OPT_GET is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_GETCONFIG(unsigned long long *o)
{
  int n = (LYD_OPT_GETCONFIG) <= 0;
  *o = (unsigned long long)((LYD_OPT_GETCONFIG) | 0);  /* check that LYD_OPT_GETCONFIG is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_NOSIBLINGS(unsigned long long *o)
{
  int n = (LYD_OPT_NOSIBLINGS) <= 0;
  *o = (unsigned long long)((LYD_OPT_NOSIBLINGS) | 0);  /* check that LYD_OPT_NOSIBLINGS is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_RPC(unsigned long long *o)
{
  int n = (LYD_OPT_RPC) <= 0;
  *o = (unsigned long long)((LYD_OPT_RPC) | 0);  /* check that LYD_OPT_RPC is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_RPCREPLY(unsigned long long *o)
{
  int n = (LYD_OPT_RPCREPLY) <= 0;
  *o = (unsigned long long)((LYD_OPT_RPCREPLY) | 0);  /* check that LYD_OPT_RPCREPLY is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_STRICT(unsigned long long *o)
{
  int n = (LYD_OPT_STRICT) <= 0;
  *o = (unsigned long long)((LYD_OPT_STRICT) | 0);  /* check that LYD_OPT_STRICT is an integer */
  return n;
}

static int _cffi_const_LYD_OPT_TRUSTED(unsigned long long *o)
{
  int n = (LYD_OPT_TRUSTED) <= 0;
  *o = (unsigned long long)((LYD_OPT_TRUSTED) | 0);  /* check that LYD_OPT_TRUSTED is an integer */
  return n;
}

static int _cffi_const_LYD_PATH_OPT_NOPARENTRET(unsigned long long *o)
{
  int n = (LYD_PATH_OPT_NOPARENTRET) <= 0;
  *o = (unsigned long long)((LYD_PATH_OPT_NOPARENTRET) | 0);  /* check that LYD_PATH_OPT_NOPARENTRET is an integer */
  return n;
}

static int _cffi_const_LYD_PATH_OPT_OUTPUT(unsigned long long *o)
{
  int n = (LYD_PATH_OPT_OUTPUT) <= 0;
  *o = (unsigned long long)((LYD_PATH_OPT_OUTPUT) | 0);  /* check that LYD_PATH_OPT_OUTPUT is an integer */
  return n;
}

static int _cffi_const_LYD_PATH_OPT_UPDATE(unsigned long long *o)
{
  int n = (LYD_PATH_OPT_UPDATE) <= 0;
  *o = (unsigned long long)((LYD_PATH_OPT_UPDATE) | 0);  /* check that LYD_PATH_OPT_UPDATE is an integer */
  return n;
}

static int _cffi_const_LYP_FORMAT(unsigned long long *o)
{
  int n = (LYP_FORMAT) <= 0;
  *o = (unsigned long long)((LYP_FORMAT) | 0);  /* check that LYP_FORMAT is an integer */
  return n;
}

static int _cffi_const_LYP_KEEPEMPTYCONT(unsigned long long *o)
{
  int n = (LYP_KEEPEMPTYCONT) <= 0;
  *o = (unsigned long long)((LYP_KEEPEMPTYCONT) | 0);  /* check that LYP_KEEPEMPTYCONT is an integer */
  return n;
}

static int _cffi_const_LYP_WD_ALL(unsigned long long *o)
{
  int n = (LYP_WD_ALL) <= 0;
  *o = (unsigned long long)((LYP_WD_ALL) | 0);  /* check that LYP_WD_ALL is an integer */
  return n;
}

static int _cffi_const_LYP_WD_TRIM(unsigned long long *o)
{
  int n = (LYP_WD_TRIM) <= 0;
  *o = (unsigned long long)((LYP_WD_TRIM) | 0);  /* check that LYP_WD_TRIM is an integer */
  return n;
}

static int _cffi_const_LYP_WITHSIBLINGS(unsigned long long *o)
{
  int n = (LYP_WITHSIBLINGS) <= 0;
  *o = (unsigned long long)((LYP_WITHSIBLINGS) | 0);  /* check that LYP_WITHSIBLINGS is an integer */
  return n;
}

static int _cffi_const_LYS_CONFIG_R(unsigned long long *o)
{
  int n = (LYS_CONFIG_R) <= 0;
  *o = (unsigned long long)((LYS_CONFIG_R) | 0);  /* check that LYS_CONFIG_R is an integer */
  return n;
}

static int _cffi_const_LYS_CONFIG_SET(unsigned long long *o)
{
  int n = (LYS_CONFIG_SET) <= 0;
  *o = (unsigned long long)((LYS_CONFIG_SET) | 0);  /* check that LYS_CONFIG_SET is an integer */
  return n;
}

static int _cffi_const_LYS_CONFIG_W(unsigned long long *o)
{
  int n = (LYS_CONFIG_W) <= 0;
  *o = (unsigned long long)((LYS_CONFIG_W) | 0);  /* check that LYS_CONFIG_W is an integer */
  return n;
}

static int _cffi_const_LYS_FENABLED(unsigned long long *o)
{
  int n = (LYS_FENABLED) <= 0;
  *o = (unsigned long long)((LYS_FENABLED) | 0);  /* check that LYS_FENABLED is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_INTONPCONT(unsigned long long *o)
{
  int n = (LYS_GETNEXT_INTONPCONT) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_INTONPCONT) | 0);  /* check that LYS_GETNEXT_INTONPCONT is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_INTOUSES(unsigned long long *o)
{
  int n = (LYS_GETNEXT_INTOUSES) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_INTOUSES) | 0);  /* check that LYS_GETNEXT_INTOUSES is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_NOSTATECHECK(unsigned long long *o)
{
  int n = (LYS_GETNEXT_NOSTATECHECK) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_NOSTATECHECK) | 0);  /* check that LYS_GETNEXT_NOSTATECHECK is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_PARENTUSES(unsigned long long *o)
{
  int n = (LYS_GETNEXT_PARENTUSES) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_PARENTUSES) | 0);  /* check that LYS_GETNEXT_PARENTUSES is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_WITHCASE(unsigned long long *o)
{
  int n = (LYS_GETNEXT_WITHCASE) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_WITHCASE) | 0);  /* check that LYS_GETNEXT_WITHCASE is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_WITHCHOICE(unsigned long long *o)
{
  int n = (LYS_GETNEXT_WITHCHOICE) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_WITHCHOICE) | 0);  /* check that LYS_GETNEXT_WITHCHOICE is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_WITHGROUPING(unsigned long long *o)
{
  int n = (LYS_GETNEXT_WITHGROUPING) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_WITHGROUPING) | 0);  /* check that LYS_GETNEXT_WITHGROUPING is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_WITHINOUT(unsigned long long *o)
{
  int n = (LYS_GETNEXT_WITHINOUT) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_WITHINOUT) | 0);  /* check that LYS_GETNEXT_WITHINOUT is an integer */
  return n;
}

static int _cffi_const_LYS_GETNEXT_WITHUSES(unsigned long long *o)
{
  int n = (LYS_GETNEXT_WITHUSES) <= 0;
  *o = (unsigned long long)((LYS_GETNEXT_WITHUSES) | 0);  /* check that LYS_GETNEXT_WITHUSES is an integer */
  return n;
}

static int _cffi_const_LYS_IFF_AND(unsigned long long *o)
{
  int n = (LYS_IFF_AND) <= 0;
  *o = (unsigned long long)((LYS_IFF_AND) | 0);  /* check that LYS_IFF_AND is an integer */
  return n;
}

static int _cffi_const_LYS_IFF_F(unsigned long long *o)
{
  int n = (LYS_IFF_F) <= 0;
  *o = (unsigned long long)((LYS_IFF_F) | 0);  /* check that LYS_IFF_F is an integer */
  return n;
}

static int _cffi_const_LYS_IFF_NOT(unsigned long long *o)
{
  int n = (LYS_IFF_NOT) <= 0;
  *o = (unsigned long long)((LYS_IFF_NOT) | 0);  /* check that LYS_IFF_NOT is an integer */
  return n;
}

static int _cffi_const_LYS_IFF_OR(unsigned long long *o)
{
  int n = (LYS_IFF_OR) <= 0;
  *o = (unsigned long long)((LYS_IFF_OR) | 0);  /* check that LYS_IFF_OR is an integer */
  return n;
}

static int _cffi_const_LYS_MAND_TRUE(unsigned long long *o)
{
  int n = (LYS_MAND_TRUE) <= 0;
  *o = (unsigned long long)((LYS_MAND_TRUE) | 0);  /* check that LYS_MAND_TRUE is an integer */
  return n;
}

static int _cffi_const_LYS_STATUS_DEPRC(unsigned long long *o)
{
  int n = (LYS_STATUS_DEPRC) <= 0;
  *o = (unsigned long long)((LYS_STATUS_DEPRC) | 0);  /* check that LYS_STATUS_DEPRC is an integer */
  return n;
}

static int _cffi_const_LYS_STATUS_OBSLT(unsigned long long *o)
{
  int n = (LYS_STATUS_OBSLT) <= 0;
  *o = (unsigned long long)((LYS_STATUS_OBSLT) | 0);  /* check that LYS_STATUS_OBSLT is an integer */
  return n;
}

static int _cffi_const_LYS_USERORDERED(unsigned long long *o)
{
  int n = (LYS_USERORDERED) <= 0;
  *o = (unsigned long long)((LYS_USERORDERED) | 0);  /* check that LYS_USERORDERED is an integer */
  return n;
}

static int _cffi_const_LY_CTX_ALLIMPLEMENTED(unsigned long long *o)
{
  int n = (LY_CTX_ALLIMPLEMENTED) <= 0;
  *o = (unsigned long long)((LY_CTX_ALLIMPLEMENTED) | 0);  /* check that LY_CTX_ALLIMPLEMENTED is an integer */
  return n;
}

static int _cffi_const_LY_CTX_DISABLE_SEARCHDIRS(unsigned long long *o)
{
  int n = (LY_CTX_DISABLE_SEARCHDIRS) <= 0;
  *o = (unsigned long long)((LY_CTX_DISABLE_SEARCHDIRS) | 0);  /* check that LY_CTX_DISABLE_SEARCHDIRS is an integer */
  return n;
}

static int _cffi_const_LY_CTX_DISABLE_SEARCHDIR_CWD(unsigned long long *o)
{
  int n = (LY_CTX_DISABLE_SEARCHDIR_CWD) <= 0;
  *o = (unsigned long long)((LY_CTX_DISABLE_SEARCHDIR_CWD) | 0);  /* check that LY_CTX_DISABLE_SEARCHDIR_CWD is an integer */
  return n;
}

static int _cffi_const_LY_CTX_NOYANGLIBRARY(unsigned long long *o)
{
  int n = (LY_CTX_NOYANGLIBRARY) <= 0;
  *o = (unsigned long long)((LY_CTX_NOYANGLIBRARY) | 0);  /* check that LY_CTX_NOYANGLIBRARY is an integer */
  return n;
}

static int _cffi_const_LY_CTX_PREFER_SEARCHDIRS(unsigned long long *o)
{
  int n = (LY_CTX_PREFER_SEARCHDIRS) <= 0;
  *o = (unsigned long long)((LY_CTX_PREFER_SEARCHDIRS) | 0);  /* check that LY_CTX_PREFER_SEARCHDIRS is an integer */
  return n;
}

static int _cffi_const_LY_CTX_TRUSTED(unsigned long long *o)
{
  int n = (LY_CTX_TRUSTED) <= 0;
  *o = (unsigned long long)((LY_CTX_TRUSTED) | 0);  /* check that LY_CTX_TRUSTED is an integer */
  return n;
}

static int _cffi_const_LY_LOLOG(unsigned long long *o)
{
  int n = (LY_LOLOG) <= 0;
  *o = (unsigned long long)((LY_LOLOG) | 0);  /* check that LY_LOLOG is an integer */
  return n;
}

static int _cffi_const_LY_LOSTORE(unsigned long long *o)
{
  int n = (LY_LOSTORE) <= 0;
  *o = (unsigned long long)((LY_LOSTORE) | 0);  /* check that LY_LOSTORE is an integer */
  return n;
}

static int _cffi_const_LY_LOSTORE_LAST(unsigned long long *o)
{
  int n = (LY_LOSTORE_LAST) <= 0;
  *o = (unsigned long long)((LY_LOSTORE_LAST) | 0);  /* check that LY_LOSTORE_LAST is an integer */
  return n;
}

static int _cffi_const_LY_REV_SIZE(unsigned long long *o)
{
  int n = (LY_REV_SIZE) <= 0;
  *o = (unsigned long long)((LY_REV_SIZE) | 0);  /* check that LY_REV_SIZE is an integer */
  if (!_cffi_check_int(*o, n, 11U))
    n |= 2;
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_ly_err_item(struct ly_err_item *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->msg; (void)tmp; }
  { char * *tmp = &p->path; (void)tmp; }
  { char * *tmp = &p->apptag; (void)tmp; }
  { struct ly_err_item * *tmp = &p->next; (void)tmp; }
}
struct _cffi_align_struct_ly_err_item { char x; struct ly_err_item y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_ly_set(struct ly_set *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->size) | 0);  /* check that 'struct ly_set.size' is an integer */
  (void)((p->number) | 0);  /* check that 'struct ly_set.number' is an integer */
  { union ly_set_set *tmp = &p->set; (void)tmp; }
}
struct _cffi_align_struct_ly_set { char x; struct ly_set y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lyd_difflist(struct lyd_difflist *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { LYD_DIFFTYPE * *tmp = &p->type; (void)tmp; }
  { struct lyd_node * * *tmp = &p->first; (void)tmp; }
  { struct lyd_node * * *tmp = &p->second; (void)tmp; }
}
struct _cffi_align_struct_lyd_difflist { char x; struct lyd_difflist y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lyd_node(struct lyd_node *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_node * *tmp = &p->schema; (void)tmp; }
  { struct lyd_node * *tmp = &p->next; (void)tmp; }
  { struct lyd_node * *tmp = &p->child; (void)tmp; }
  { struct lyd_node * *tmp = &p->parent; (void)tmp; }
}
struct _cffi_align_struct_lyd_node { char x; struct lyd_node y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lyd_node_leaf_list(struct lyd_node_leaf_list *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_node * *tmp = &p->schema; (void)tmp; }
  { struct lyd_node * *tmp = &p->next; (void)tmp; }
  { struct lyd_node * *tmp = &p->parent; (void)tmp; }
  { char const * *tmp = &p->value_str; (void)tmp; }
  { lyd_val *tmp = &p->value; (void)tmp; }
  { LY_DATA_TYPE *tmp = &p->value_type; (void)tmp; }
}
struct _cffi_align_struct_lyd_node_leaf_list { char x; struct lyd_node_leaf_list y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_ext(struct lys_ext *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { struct lys_module * *tmp = &p->module; (void)tmp; }
}
struct _cffi_align_struct_lys_ext { char x; struct lys_ext y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_ext_instance(struct lys_ext_instance *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_ext * *tmp = &p->def; (void)tmp; }
  { char const * *tmp = &p->arg_value; (void)tmp; }
}
struct _cffi_align_struct_lys_ext_instance { char x; struct lys_ext_instance y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_feature(struct lys_feature *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
  { char const * *tmp = &p->ref; (void)tmp; }
  (void)((p->flags) | 0);  /* check that 'struct lys_feature.flags' is an integer */
  (void)((p->iffeature_size) | 0);  /* check that 'struct lys_feature.iffeature_size' is an integer */
  { struct lys_iffeature * *tmp = &p->iffeature; (void)tmp; }
  { struct lys_module * *tmp = &p->module; (void)tmp; }
}
struct _cffi_align_struct_lys_feature { char x; struct lys_feature y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_iffeature(struct lys_iffeature *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { uint8_t * *tmp = &p->expr; (void)tmp; }
  { struct lys_feature * * *tmp = &p->features; (void)tmp; }
}
struct _cffi_align_struct_lys_iffeature { char x; struct lys_iffeature y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_module(struct lys_module *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->prefix; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
  { char const * *tmp = &p->filepath; (void)tmp; }
  (void)((p->rev_size) | 0);  /* check that 'struct lys_module.rev_size' is an integer */
  (void)((p->features_size) | 0);  /* check that 'struct lys_module.features_size' is an integer */
  { struct lys_revision * *tmp = &p->rev; (void)tmp; }
  { struct lys_feature * *tmp = &p->features; (void)tmp; }
}
struct _cffi_align_struct_lys_module { char x; struct lys_module y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_node(struct lys_node *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
  (void)((p->flags) | 0);  /* check that 'struct lys_node.flags' is an integer */
  (void)((p->ext_size) | 0);  /* check that 'struct lys_node.ext_size' is an integer */
  (void)((p->iffeature_size) | 0);  /* check that 'struct lys_node.iffeature_size' is an integer */
  { struct lys_ext_instance * * *tmp = &p->ext; (void)tmp; }
  { struct lys_iffeature * *tmp = &p->iffeature; (void)tmp; }
  { LYS_NODE *tmp = &p->nodetype; (void)tmp; }
}
struct _cffi_align_struct_lys_node { char x; struct lys_node y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_node_container(struct lys_node_container *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->must_size) | 0);  /* check that 'struct lys_node_container.must_size' is an integer */
  { struct lys_restr * *tmp = &p->must; (void)tmp; }
  { char const * *tmp = &p->presence; (void)tmp; }
}
struct _cffi_align_struct_lys_node_container { char x; struct lys_node_container y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_node_leaf(struct lys_node_leaf *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->must_size) | 0);  /* check that 'struct lys_node_leaf.must_size' is an integer */
  { struct lys_restr * *tmp = &p->must; (void)tmp; }
  { struct lys_type *tmp = &p->type; (void)tmp; }
  { char const * *tmp = &p->units; (void)tmp; }
  { char const * *tmp = &p->dflt; (void)tmp; }
}
struct _cffi_align_struct_lys_node_leaf { char x; struct lys_node_leaf y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_node_leaflist(struct lys_node_leaflist *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->must_size) | 0);  /* check that 'struct lys_node_leaflist.must_size' is an integer */
  { struct lys_restr * *tmp = &p->must; (void)tmp; }
  { struct lys_type *tmp = &p->type; (void)tmp; }
  { char const * *tmp = &p->units; (void)tmp; }
  (void)((p->min) | 0);  /* check that 'struct lys_node_leaflist.min' is an integer */
  (void)((p->max) | 0);  /* check that 'struct lys_node_leaflist.max' is an integer */
  (void)((p->dflt_size) | 0);  /* check that 'struct lys_node_leaflist.dflt_size' is an integer */
  { char const * * *tmp = &p->dflt; (void)tmp; }
}
struct _cffi_align_struct_lys_node_leaflist { char x; struct lys_node_leaflist y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_node_list(struct lys_node_list *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->must_size) | 0);  /* check that 'struct lys_node_list.must_size' is an integer */
  { struct lys_restr * *tmp = &p->must; (void)tmp; }
  (void)((p->keys_size) | 0);  /* check that 'struct lys_node_list.keys_size' is an integer */
  { struct lys_node_leaf * * *tmp = &p->keys; (void)tmp; }
  (void)((p->min) | 0);  /* check that 'struct lys_node_list.min' is an integer */
  (void)((p->max) | 0);  /* check that 'struct lys_node_list.max' is an integer */
}
struct _cffi_align_struct_lys_node_list { char x; struct lys_node_list y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_restr(struct lys_restr *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->expr; (void)tmp; }
}
struct _cffi_align_struct_lys_restr { char x; struct lys_restr y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_revision(struct lys_revision *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char(*tmp)[11] = &p->date; (void)tmp; }
  (void)((p->ext_size) | 0);  /* check that 'struct lys_revision.ext_size' is an integer */
  { struct lys_ext_instance * * *tmp = &p->ext; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
  { char const * *tmp = &p->ref; (void)tmp; }
}
struct _cffi_align_struct_lys_revision { char x; struct lys_revision y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_tpdf(struct lys_tpdf *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
  (void)((p->ext_size) | 0);  /* check that 'struct lys_tpdf.ext_size' is an integer */
  { struct lys_ext_instance * * *tmp = &p->ext; (void)tmp; }
  { char const * *tmp = &p->units; (void)tmp; }
  { struct lys_type *tmp = &p->type; (void)tmp; }
  { struct lys_module * *tmp = &p->module; (void)tmp; }
  { char const * *tmp = &p->dflt; (void)tmp; }
}
struct _cffi_align_struct_lys_tpdf { char x; struct lys_tpdf y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type(struct lys_type *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { LY_DATA_TYPE *tmp = &p->base; (void)tmp; }
  (void)((p->value_flags) | 0);  /* check that 'struct lys_type.value_flags' is an integer */
  (void)((p->ext_size) | 0);  /* check that 'struct lys_type.ext_size' is an integer */
  { struct lys_ext_instance * * *tmp = &p->ext; (void)tmp; }
  { struct lys_tpdf * *tmp = &p->der; (void)tmp; }
  { struct lys_tpdf * *tmp = &p->parent; (void)tmp; }
  { union lys_type_info *tmp = &p->info; (void)tmp; }
}
struct _cffi_align_struct_lys_type { char x; struct lys_type y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_bit(struct lys_type_bit *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
  (void)((p->pos) | 0);  /* check that 'struct lys_type_bit.pos' is an integer */
}
struct _cffi_align_struct_lys_type_bit { char x; struct lys_type_bit y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_enum(struct lys_type_enum *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->dsc; (void)tmp; }
}
struct _cffi_align_struct_lys_type_enum { char x; struct lys_type_enum y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_binary(struct lys_type_info_binary *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_restr * *tmp = &p->length; (void)tmp; }
}
struct _cffi_align_struct_lys_type_info_binary { char x; struct lys_type_info_binary y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_bits(struct lys_type_info_bits *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_type_bit * *tmp = &p->bit; (void)tmp; }
  (void)((p->count) | 0);  /* check that 'struct lys_type_info_bits.count' is an integer */
}
struct _cffi_align_struct_lys_type_info_bits { char x; struct lys_type_info_bits y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_dec64(struct lys_type_info_dec64 *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_restr * *tmp = &p->range; (void)tmp; }
}
struct _cffi_align_struct_lys_type_info_dec64 { char x; struct lys_type_info_dec64 y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_enums(struct lys_type_info_enums *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_type_enum * *tmp = &p->enm; (void)tmp; }
  (void)((p->count) | 0);  /* check that 'struct lys_type_info_enums.count' is an integer */
}
struct _cffi_align_struct_lys_type_info_enums { char x; struct lys_type_info_enums y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_lref(struct lys_type_info_lref *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->path; (void)tmp; }
  { struct lys_node_leaf * *tmp = &p->target; (void)tmp; }
  (void)((p->req) | 0);  /* check that 'struct lys_type_info_lref.req' is an integer */
}
struct _cffi_align_struct_lys_type_info_lref { char x; struct lys_type_info_lref y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_num(struct lys_type_info_num *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_restr * *tmp = &p->range; (void)tmp; }
}
struct _cffi_align_struct_lys_type_info_num { char x; struct lys_type_info_num y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_str(struct lys_type_info_str *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_restr * *tmp = &p->length; (void)tmp; }
  { struct lys_restr * *tmp = &p->patterns; (void)tmp; }
  (void)((p->pat_count) | 0);  /* check that 'struct lys_type_info_str.pat_count' is an integer */
}
struct _cffi_align_struct_lys_type_info_str { char x; struct lys_type_info_str y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_lys_type_info_union(struct lys_type_info_union *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_type * *tmp = &p->types; (void)tmp; }
  (void)((p->count) | 0);  /* check that 'struct lys_type_info_union.count' is an integer */
  (void)((p->has_ptr_type) | 0);  /* check that 'struct lys_type_info_union.has_ptr_type' is an integer */
}
struct _cffi_align_struct_lys_type_info_union { char x; struct lys_type_info_union y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_union_ly_set_set(union ly_set_set *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_node * * *tmp = &p->s; (void)tmp; }
  { struct lyd_node * * *tmp = &p->d; (void)tmp; }
}
struct _cffi_align_union_ly_set_set { char x; union ly_set_set y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__lyd_val(lyd_val *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->bln) | 0);  /* check that 'lyd_val.bln' is an integer */
  { struct lyd_node * *tmp = &p->leafref; (void)tmp; }
}
struct _cffi_align__lyd_val { char x; lyd_val y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_union_lys_type_info(union lys_type_info *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { struct lys_type_info_binary *tmp = &p->binary; (void)tmp; }
  { struct lys_type_info_bits *tmp = &p->bits; (void)tmp; }
  { struct lys_type_info_dec64 *tmp = &p->dec64; (void)tmp; }
  { struct lys_type_info_enums *tmp = &p->enums; (void)tmp; }
  { struct lys_type_info_num *tmp = &p->num; (void)tmp; }
  { struct lys_type_info_lref *tmp = &p->lref; (void)tmp; }
  { struct lys_type_info_str *tmp = &p->str; (void)tmp; }
  { struct lys_type_info_union *tmp = &p->uni; (void)tmp; }
}
struct _cffi_align_union_lys_type_info { char x; union lys_type_info y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "LYD_ANYDATA_CONSTSTRING", (void *)_cffi_const_LYD_ANYDATA_CONSTSTRING, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_DIFFOPT_NOSIBLINGS", (void *)_cffi_const_LYD_DIFFOPT_NOSIBLINGS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_DIFFOPT_WITHDEFAULTS", (void *)_cffi_const_LYD_DIFFOPT_WITHDEFAULTS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_DIFF_CHANGED", (void *)_cffi_const_LYD_DIFF_CHANGED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_DIFF_CREATED", (void *)_cffi_const_LYD_DIFF_CREATED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_DIFF_DELETED", (void *)_cffi_const_LYD_DIFF_DELETED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_DIFF_END", (void *)_cffi_const_LYD_DIFF_END, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_DIFF_MOVEDAFTER1", (void *)_cffi_const_LYD_DIFF_MOVEDAFTER1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_DIFF_MOVEDAFTER2", (void *)_cffi_const_LYD_DIFF_MOVEDAFTER2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_JSON", (void *)_cffi_const_LYD_JSON, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_LYB", (void *)_cffi_const_LYD_LYB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYD_OPT_CONFIG", (void *)_cffi_const_LYD_OPT_CONFIG, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_DATA", (void *)_cffi_const_LYD_OPT_DATA, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_DATA_NO_YANGLIB", (void *)_cffi_const_LYD_OPT_DATA_NO_YANGLIB, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_DESTRUCT", (void *)_cffi_const_LYD_OPT_DESTRUCT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_EDIT", (void *)_cffi_const_LYD_OPT_EDIT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_EXPLICIT", (void *)_cffi_const_LYD_OPT_EXPLICIT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_GET", (void *)_cffi_const_LYD_OPT_GET, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_GETCONFIG", (void *)_cffi_const_LYD_OPT_GETCONFIG, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_NOSIBLINGS", (void *)_cffi_const_LYD_OPT_NOSIBLINGS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_RPC", (void *)_cffi_const_LYD_OPT_RPC, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_RPCREPLY", (void *)_cffi_const_LYD_OPT_RPCREPLY, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_STRICT", (void *)_cffi_const_LYD_OPT_STRICT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_OPT_TRUSTED", (void *)_cffi_const_LYD_OPT_TRUSTED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_PATH_OPT_NOPARENTRET", (void *)_cffi_const_LYD_PATH_OPT_NOPARENTRET, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_PATH_OPT_OUTPUT", (void *)_cffi_const_LYD_PATH_OPT_OUTPUT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_PATH_OPT_UPDATE", (void *)_cffi_const_LYD_PATH_OPT_UPDATE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYD_XML", (void *)_cffi_const_LYD_XML, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYP_FORMAT", (void *)_cffi_const_LYP_FORMAT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYP_KEEPEMPTYCONT", (void *)_cffi_const_LYP_KEEPEMPTYCONT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYP_WD_ALL", (void *)_cffi_const_LYP_WD_ALL, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYP_WD_TRIM", (void *)_cffi_const_LYP_WD_TRIM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYP_WITHSIBLINGS", (void *)_cffi_const_LYP_WITHSIBLINGS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_ACTION", (void *)_cffi_const_LYS_ACTION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_ANYDATA", (void *)_cffi_const_LYS_ANYDATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_ANYXML", (void *)_cffi_const_LYS_ANYXML, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_AUGMENT", (void *)_cffi_const_LYS_AUGMENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_CASE", (void *)_cffi_const_LYS_CASE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_CHOICE", (void *)_cffi_const_LYS_CHOICE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_CONFIG_R", (void *)_cffi_const_LYS_CONFIG_R, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_CONFIG_SET", (void *)_cffi_const_LYS_CONFIG_SET, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_CONFIG_W", (void *)_cffi_const_LYS_CONFIG_W, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_CONTAINER", (void *)_cffi_const_LYS_CONTAINER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_EXT", (void *)_cffi_const_LYS_EXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_FENABLED", (void *)_cffi_const_LYS_FENABLED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_INTONPCONT", (void *)_cffi_const_LYS_GETNEXT_INTONPCONT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_INTOUSES", (void *)_cffi_const_LYS_GETNEXT_INTOUSES, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_NOSTATECHECK", (void *)_cffi_const_LYS_GETNEXT_NOSTATECHECK, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_PARENTUSES", (void *)_cffi_const_LYS_GETNEXT_PARENTUSES, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_WITHCASE", (void *)_cffi_const_LYS_GETNEXT_WITHCASE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_WITHCHOICE", (void *)_cffi_const_LYS_GETNEXT_WITHCHOICE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_WITHGROUPING", (void *)_cffi_const_LYS_GETNEXT_WITHGROUPING, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_WITHINOUT", (void *)_cffi_const_LYS_GETNEXT_WITHINOUT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GETNEXT_WITHUSES", (void *)_cffi_const_LYS_GETNEXT_WITHUSES, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_GROUPING", (void *)_cffi_const_LYS_GROUPING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_IFF_AND", (void *)_cffi_const_LYS_IFF_AND, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_IFF_F", (void *)_cffi_const_LYS_IFF_F, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_IFF_NOT", (void *)_cffi_const_LYS_IFF_NOT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_IFF_OR", (void *)_cffi_const_LYS_IFF_OR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_INPUT", (void *)_cffi_const_LYS_INPUT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_IN_UNKNOWN", (void *)_cffi_const_LYS_IN_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_IN_YANG", (void *)_cffi_const_LYS_IN_YANG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_IN_YIN", (void *)_cffi_const_LYS_IN_YIN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_LEAF", (void *)_cffi_const_LYS_LEAF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_LEAFLIST", (void *)_cffi_const_LYS_LEAFLIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_LIST", (void *)_cffi_const_LYS_LIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_MAND_TRUE", (void *)_cffi_const_LYS_MAND_TRUE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_NOTIF", (void *)_cffi_const_LYS_NOTIF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUTPUT", (void *)_cffi_const_LYS_OUTPUT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUT_INFO", (void *)_cffi_const_LYS_OUT_INFO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUT_JSON", (void *)_cffi_const_LYS_OUT_JSON, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUT_TREE", (void *)_cffi_const_LYS_OUT_TREE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUT_UNKNOWN", (void *)_cffi_const_LYS_OUT_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUT_YANG", (void *)_cffi_const_LYS_OUT_YANG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_OUT_YIN", (void *)_cffi_const_LYS_OUT_YIN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_RPC", (void *)_cffi_const_LYS_RPC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_STATUS_DEPRC", (void *)_cffi_const_LYS_STATUS_DEPRC, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_STATUS_OBSLT", (void *)_cffi_const_LYS_STATUS_OBSLT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_UNKNOWN", (void *)_cffi_const_LYS_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYS_USERORDERED", (void *)_cffi_const_LYS_USERORDERED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LYS_USES", (void *)_cffi_const_LYS_USES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYVE_PATH_EXISTS", (void *)_cffi_const_LYVE_PATH_EXISTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LYVE_SUCCESS", (void *)_cffi_const_LYVE_SUCCESS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_CTX_ALLIMPLEMENTED", (void *)_cffi_const_LY_CTX_ALLIMPLEMENTED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_CTX_DISABLE_SEARCHDIRS", (void *)_cffi_const_LY_CTX_DISABLE_SEARCHDIRS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_CTX_DISABLE_SEARCHDIR_CWD", (void *)_cffi_const_LY_CTX_DISABLE_SEARCHDIR_CWD, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_CTX_NOYANGLIBRARY", (void *)_cffi_const_LY_CTX_NOYANGLIBRARY, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_CTX_PREFER_SEARCHDIRS", (void *)_cffi_const_LY_CTX_PREFER_SEARCHDIRS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_CTX_TRUSTED", (void *)_cffi_const_LY_CTX_TRUSTED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_LLDBG", (void *)_cffi_const_LY_LLDBG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_LLERR", (void *)_cffi_const_LY_LLERR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_LLVRB", (void *)_cffi_const_LY_LLVRB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_LLWRN", (void *)_cffi_const_LY_LLWRN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_LOLOG", (void *)_cffi_const_LY_LOLOG, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_LOSTORE", (void *)_cffi_const_LY_LOSTORE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_LOSTORE_LAST", (void *)_cffi_const_LY_LOSTORE_LAST, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_REV_SIZE", (void *)_cffi_const_LY_REV_SIZE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "LY_SUCCESS", (void *)_cffi_const_LY_SUCCESS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_BINARY", (void *)_cffi_const_LY_TYPE_BINARY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_BITS", (void *)_cffi_const_LY_TYPE_BITS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_BOOL", (void *)_cffi_const_LY_TYPE_BOOL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_DEC64", (void *)_cffi_const_LY_TYPE_DEC64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_DER", (void *)_cffi_const_LY_TYPE_DER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_EMPTY", (void *)_cffi_const_LY_TYPE_EMPTY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_ENUM", (void *)_cffi_const_LY_TYPE_ENUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_IDENT", (void *)_cffi_const_LY_TYPE_IDENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_INST", (void *)_cffi_const_LY_TYPE_INST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_INT16", (void *)_cffi_const_LY_TYPE_INT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_INT32", (void *)_cffi_const_LY_TYPE_INT32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_INT64", (void *)_cffi_const_LY_TYPE_INT64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_INT8", (void *)_cffi_const_LY_TYPE_INT8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_LEAFREF", (void *)_cffi_const_LY_TYPE_LEAFREF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_STRING", (void *)_cffi_const_LY_TYPE_STRING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_UINT16", (void *)_cffi_const_LY_TYPE_UINT16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_UINT32", (void *)_cffi_const_LY_TYPE_UINT32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_UINT64", (void *)_cffi_const_LY_TYPE_UINT64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_UINT8", (void *)_cffi_const_LY_TYPE_UINT8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_UNION", (void *)_cffi_const_LY_TYPE_UNION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "LY_TYPE_UNKNOWN", (void *)_cffi_const_LY_TYPE_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "free", (void *)_cffi_f_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 211), (void *)_cffi_d_free },
  { "ly_ctx_destroy", (void *)_cffi_f_ly_ctx_destroy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 198), (void *)_cffi_d_ly_ctx_destroy },
  { "ly_ctx_find_path", (void *)_cffi_f_ly_ctx_find_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 85), (void *)_cffi_d_ly_ctx_find_path },
  { "ly_ctx_get_module", (void *)_cffi_f_ly_ctx_get_module, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 160), (void *)_cffi_d_ly_ctx_get_module },
  { "ly_ctx_get_module_iter", (void *)_cffi_f_ly_ctx_get_module_iter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 166), (void *)_cffi_d_ly_ctx_get_module_iter },
  { "ly_ctx_load_module", (void *)_cffi_f_ly_ctx_load_module, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 150), (void *)_cffi_d_ly_ctx_load_module },
  { "ly_ctx_new", (void *)_cffi_f_ly_ctx_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 78), (void *)_cffi_d_ly_ctx_new },
  { "ly_ctx_set_searchdir", (void *)_cffi_f_ly_ctx_set_searchdir, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 56), (void *)_cffi_d_ly_ctx_set_searchdir },
  { "ly_err_clean", (void *)_cffi_f_ly_err_clean, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 194), (void *)_cffi_d_ly_err_clean },
  { "ly_err_first", (void *)_cffi_f_ly_err_first, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 82), (void *)_cffi_d_ly_err_first },
  { "ly_log_options", (void *)_cffi_f_ly_log_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 39), (void *)_cffi_d_ly_log_options },
  { "ly_set_free", (void *)_cffi_f_ly_set_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 202), (void *)_cffi_d_ly_set_free },
  { "ly_set_log_clb", (void *)_cffi_f_ly_set_log_clb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 214), (void *)_cffi_d_ly_set_log_clb },
  { "ly_vecode", (void *)_cffi_f_ly_vecode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 5), (void *)_cffi_d_ly_vecode },
  { "ly_verb", (void *)_cffi_f_ly_verb, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 2), (void *)_cffi_d_ly_verb },
  { "lyd_dec64_to_double", (void *)_cffi_f_lyd_dec64_to_double, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 22), (void *)_cffi_d_lyd_dec64_to_double },
  { "lyd_diff", (void *)_cffi_f_lyd_diff, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 97), (void *)_cffi_d_lyd_diff },
  { "lyd_find_instance", (void *)_cffi_f_lyd_find_instance, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 93), (void *)_cffi_d_lyd_find_instance },
  { "lyd_find_path", (void *)_cffi_f_lyd_find_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 89), (void *)_cffi_d_lyd_find_path },
  { "lyd_first_sibling", (void *)_cffi_f_lyd_first_sibling, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 114), (void *)_cffi_d_lyd_first_sibling },
  { "lyd_free", (void *)_cffi_f_lyd_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 208), (void *)_cffi_d_lyd_free },
  { "lyd_free_diff", (void *)_cffi_f_lyd_free_diff, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 205), (void *)_cffi_d_lyd_free_diff },
  { "lyd_free_withsiblings", (void *)_cffi_f_lyd_free_withsiblings, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 208), (void *)_cffi_d_lyd_free_withsiblings },
  { "lyd_merge", (void *)_cffi_f_lyd_merge, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 65), (void *)_cffi_d_lyd_merge },
  { "lyd_new", (void *)_cffi_f_lyd_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 125), (void *)_cffi_d_lyd_new },
  { "lyd_new_leaf", (void *)_cffi_f_lyd_new_leaf, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 130), (void *)_cffi_d_lyd_new_leaf },
  { "lyd_new_output", (void *)_cffi_f_lyd_new_output, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 125), (void *)_cffi_d_lyd_new_output },
  { "lyd_new_output_leaf", (void *)_cffi_f_lyd_new_output_leaf, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 130), (void *)_cffi_d_lyd_new_output_leaf },
  { "lyd_new_path", (void *)_cffi_f_lyd_new_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 117), (void *)_cffi_d_lyd_new_path },
  { "lyd_node_module", (void *)_cffi_f_lyd_node_module, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 136), (void *)_cffi_d_lyd_node_module },
  { "lyd_node_should_print", (void *)_cffi_f_lyd_node_should_print, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 70), (void *)_cffi_d_lyd_node_should_print },
  { "lyd_parse_fd", (void *)_cffi_const_lyd_parse_fd, _CFFI_OP(_CFFI_OP_CONSTANT, 236), (void *)0 },
  { "lyd_parse_mem", (void *)_cffi_const_lyd_parse_mem, _CFFI_OP(_CFFI_OP_CONSTANT, 235), (void *)0 },
  { "lyd_path", (void *)_cffi_f_lyd_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 8), (void *)_cffi_d_lyd_path },
  { "lyd_print_fd", (void *)_cffi_f_lyd_print_fd, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 42), (void *)_cffi_d_lyd_print_fd },
  { "lyd_print_mem", (void *)_cffi_f_lyd_print_mem, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 25), (void *)_cffi_d_lyd_print_mem },
  { "lyd_validate", (void *)_cffi_f_lyd_validate, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 60), (void *)_cffi_d_lyd_validate },
  { "lypy_get_errno", (void *)_cffi_f_lypy_get_errno, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 0), (void *)_cffi_d_lypy_get_errno },
  { "lypy_log_cb", (void *)&_cffi_externpy__lypy_log_cb, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 215), (void *)lypy_log_cb },
  { "lypy_module_implemented", (void *)_cffi_f_lypy_module_implemented, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 183), (void *)_cffi_d_lypy_module_implemented },
  { "lypy_set_errno", (void *)_cffi_f_lypy_set_errno, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 186), (void *)_cffi_d_lypy_set_errno },
  { "lys_data_path", (void *)_cffi_f_lys_data_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 11), (void *)_cffi_d_lys_data_path },
  { "lys_data_path_pattern", (void *)_cffi_f_lys_data_path_pattern, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 14), (void *)_cffi_d_lys_data_path_pattern },
  { "lys_features_disable", (void *)_cffi_f_lys_features_disable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 74), (void *)_cffi_d_lys_features_disable },
  { "lys_features_enable", (void *)_cffi_f_lys_features_enable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 74), (void *)_cffi_d_lys_features_enable },
  { "lys_features_state", (void *)_cffi_f_lys_features_state, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 74), (void *)_cffi_d_lys_features_state },
  { "lys_getnext", (void *)_cffi_f_lys_getnext, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 173), (void *)_cffi_d_lys_getnext },
  { "lys_is_key", (void *)_cffi_f_lys_is_key, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 179), (void *)_cffi_d_lys_is_key },
  { "lys_main_module", (void *)_cffi_f_lys_main_module, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 139), (void *)_cffi_d_lys_main_module },
  { "lys_node_module", (void *)_cffi_f_lys_node_module, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 142), (void *)_cffi_d_lys_node_module },
  { "lys_parent", (void *)_cffi_f_lys_parent, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 170), (void *)_cffi_d_lys_parent },
  { "lys_parse_fd", (void *)_cffi_f_lys_parse_fd, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 155), (void *)_cffi_d_lys_parse_fd },
  { "lys_parse_mem", (void *)_cffi_f_lys_parse_mem, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 145), (void *)_cffi_d_lys_parse_mem },
  { "lys_path", (void *)_cffi_f_lys_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 18), (void *)_cffi_d_lys_path },
  { "lys_print_fd", (void *)_cffi_f_lys_print_fd, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 48), (void *)_cffi_d_lys_print_fd },
  { "lys_print_mem", (void *)_cffi_f_lys_print_mem, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 31), (void *)_cffi_d_lys_print_mem },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "msg", offsetof(struct ly_err_item, msg),
           sizeof(((struct ly_err_item *)0)->msg),
           _CFFI_OP(_CFFI_OP_NOOP, 223) },
  { "path", offsetof(struct ly_err_item, path),
            sizeof(((struct ly_err_item *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 223) },
  { "apptag", offsetof(struct ly_err_item, apptag),
              sizeof(((struct ly_err_item *)0)->apptag),
              _CFFI_OP(_CFFI_OP_NOOP, 223) },
  { "next", offsetof(struct ly_err_item, next),
            sizeof(((struct ly_err_item *)0)->next),
            _CFFI_OP(_CFFI_OP_NOOP, 196) },
  { "size", offsetof(struct ly_set, size),
            sizeof(((struct ly_set *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 286) },
  { "number", offsetof(struct ly_set, number),
              sizeof(((struct ly_set *)0)->number),
              _CFFI_OP(_CFFI_OP_NOOP, 286) },
  { "set", offsetof(struct ly_set, set),
           sizeof(((struct ly_set *)0)->set),
           _CFFI_OP(_CFFI_OP_NOOP, 284) },
  { "type", offsetof(struct lyd_difflist, type),
            sizeof(((struct lyd_difflist *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 218) },
  { "first", offsetof(struct lyd_difflist, first),
             sizeof(((struct lyd_difflist *)0)->first),
             _CFFI_OP(_CFFI_OP_NOOP, 61) },
  { "second", offsetof(struct lyd_difflist, second),
              sizeof(((struct lyd_difflist *)0)->second),
              _CFFI_OP(_CFFI_OP_NOOP, 61) },
  { "schema", offsetof(struct lyd_node, schema),
              sizeof(((struct lyd_node *)0)->schema),
              _CFFI_OP(_CFFI_OP_NOOP, 252) },
  { "next", offsetof(struct lyd_node, next),
            sizeof(((struct lyd_node *)0)->next),
            _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "child", offsetof(struct lyd_node, child),
             sizeof(((struct lyd_node *)0)->child),
             _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "parent", offsetof(struct lyd_node, parent),
              sizeof(((struct lyd_node *)0)->parent),
              _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "schema", offsetof(struct lyd_node_leaf_list, schema),
              sizeof(((struct lyd_node_leaf_list *)0)->schema),
              _CFFI_OP(_CFFI_OP_NOOP, 252) },
  { "next", offsetof(struct lyd_node_leaf_list, next),
            sizeof(((struct lyd_node_leaf_list *)0)->next),
            _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "parent", offsetof(struct lyd_node_leaf_list, parent),
              sizeof(((struct lyd_node_leaf_list *)0)->parent),
              _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "value_str", offsetof(struct lyd_node_leaf_list, value_str),
                 sizeof(((struct lyd_node_leaf_list *)0)->value_str),
                 _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "value", offsetof(struct lyd_node_leaf_list, value),
             sizeof(((struct lyd_node_leaf_list *)0)->value),
             _CFFI_OP(_CFFI_OP_NOOP, 230) },
  { "value_type", offsetof(struct lyd_node_leaf_list, value_type),
                  sizeof(((struct lyd_node_leaf_list *)0)->value_type),
                  _CFFI_OP(_CFFI_OP_NOOP, 221) },
  { "name", offsetof(struct lys_ext, name),
            sizeof(((struct lys_ext *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "module", offsetof(struct lys_ext, module),
              sizeof(((struct lys_ext *)0)->module),
              _CFFI_OP(_CFFI_OP_NOOP, 249) },
  { "def", offsetof(struct lys_ext_instance, def),
           sizeof(((struct lys_ext_instance *)0)->def),
           _CFFI_OP(_CFFI_OP_NOOP, 239) },
  { "arg_value", offsetof(struct lys_ext_instance, arg_value),
                 sizeof(((struct lys_ext_instance *)0)->arg_value),
                 _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "name", offsetof(struct lys_feature, name),
            sizeof(((struct lys_feature *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dsc", offsetof(struct lys_feature, dsc),
           sizeof(((struct lys_feature *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "ref", offsetof(struct lys_feature, ref),
           sizeof(((struct lys_feature *)0)->ref),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "flags", offsetof(struct lys_feature, flags),
             sizeof(((struct lys_feature *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 281) },
  { "iffeature_size", offsetof(struct lys_feature, iffeature_size),
                      sizeof(((struct lys_feature *)0)->iffeature_size),
                      _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "iffeature", offsetof(struct lys_feature, iffeature),
                 sizeof(((struct lys_feature *)0)->iffeature),
                 _CFFI_OP(_CFFI_OP_NOOP, 247) },
  { "module", offsetof(struct lys_feature, module),
              sizeof(((struct lys_feature *)0)->module),
              _CFFI_OP(_CFFI_OP_NOOP, 249) },
  { "expr", offsetof(struct lys_iffeature, expr),
            sizeof(((struct lys_iffeature *)0)->expr),
            _CFFI_OP(_CFFI_OP_NOOP, 181) },
  { "features", offsetof(struct lys_iffeature, features),
                sizeof(((struct lys_iffeature *)0)->features),
                _CFFI_OP(_CFFI_OP_NOOP, 244) },
  { "name", offsetof(struct lys_module, name),
            sizeof(((struct lys_module *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "prefix", offsetof(struct lys_module, prefix),
              sizeof(((struct lys_module *)0)->prefix),
              _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dsc", offsetof(struct lys_module, dsc),
           sizeof(((struct lys_module *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "filepath", offsetof(struct lys_module, filepath),
                sizeof(((struct lys_module *)0)->filepath),
                _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "rev_size", offsetof(struct lys_module, rev_size),
                sizeof(((struct lys_module *)0)->rev_size),
                _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "features_size", offsetof(struct lys_module, features_size),
                     sizeof(((struct lys_module *)0)->features_size),
                     _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "rev", offsetof(struct lys_module, rev),
           sizeof(((struct lys_module *)0)->rev),
           _CFFI_OP(_CFFI_OP_NOOP, 263) },
  { "features", offsetof(struct lys_module, features),
                sizeof(((struct lys_module *)0)->features),
                _CFFI_OP(_CFFI_OP_NOOP, 245) },
  { "name", offsetof(struct lys_node, name),
            sizeof(((struct lys_node *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dsc", offsetof(struct lys_node, dsc),
           sizeof(((struct lys_node *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "flags", offsetof(struct lys_node, flags),
             sizeof(((struct lys_node *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 281) },
  { "ext_size", offsetof(struct lys_node, ext_size),
                sizeof(((struct lys_node *)0)->ext_size),
                _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "iffeature_size", offsetof(struct lys_node, iffeature_size),
                      sizeof(((struct lys_node *)0)->iffeature_size),
                      _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "ext", offsetof(struct lys_node, ext),
           sizeof(((struct lys_node *)0)->ext),
           _CFFI_OP(_CFFI_OP_NOOP, 241) },
  { "iffeature", offsetof(struct lys_node, iffeature),
                 sizeof(((struct lys_node *)0)->iffeature),
                 _CFFI_OP(_CFFI_OP_NOOP, 247) },
  { "nodetype", offsetof(struct lys_node, nodetype),
                sizeof(((struct lys_node *)0)->nodetype),
                _CFFI_OP(_CFFI_OP_NOOP, 220) },
  { "must_size", offsetof(struct lys_node_container, must_size),
                 sizeof(((struct lys_node_container *)0)->must_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "must", offsetof(struct lys_node_container, must),
            sizeof(((struct lys_node_container *)0)->must),
            _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "presence", offsetof(struct lys_node_container, presence),
                sizeof(((struct lys_node_container *)0)->presence),
                _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "must_size", offsetof(struct lys_node_leaf, must_size),
                 sizeof(((struct lys_node_leaf *)0)->must_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "must", offsetof(struct lys_node_leaf, must),
            sizeof(((struct lys_node_leaf *)0)->must),
            _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "type", offsetof(struct lys_node_leaf, type),
            sizeof(((struct lys_node_leaf *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 268) },
  { "units", offsetof(struct lys_node_leaf, units),
             sizeof(((struct lys_node_leaf *)0)->units),
             _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dflt", offsetof(struct lys_node_leaf, dflt),
            sizeof(((struct lys_node_leaf *)0)->dflt),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "must_size", offsetof(struct lys_node_leaflist, must_size),
                 sizeof(((struct lys_node_leaflist *)0)->must_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "must", offsetof(struct lys_node_leaflist, must),
            sizeof(((struct lys_node_leaflist *)0)->must),
            _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "type", offsetof(struct lys_node_leaflist, type),
            sizeof(((struct lys_node_leaflist *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 268) },
  { "units", offsetof(struct lys_node_leaflist, units),
             sizeof(((struct lys_node_leaflist *)0)->units),
             _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "min", offsetof(struct lys_node_leaflist, min),
           sizeof(((struct lys_node_leaflist *)0)->min),
           _CFFI_OP(_CFFI_OP_NOOP, 282) },
  { "max", offsetof(struct lys_node_leaflist, max),
           sizeof(((struct lys_node_leaflist *)0)->max),
           _CFFI_OP(_CFFI_OP_NOOP, 282) },
  { "dflt_size", offsetof(struct lys_node_leaflist, dflt_size),
                 sizeof(((struct lys_node_leaflist *)0)->dflt_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "dflt", offsetof(struct lys_node_leaflist, dflt),
            sizeof(((struct lys_node_leaflist *)0)->dflt),
            _CFFI_OP(_CFFI_OP_NOOP, 224) },
  { "must_size", offsetof(struct lys_node_list, must_size),
                 sizeof(((struct lys_node_list *)0)->must_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "must", offsetof(struct lys_node_list, must),
            sizeof(((struct lys_node_list *)0)->must),
            _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "keys_size", offsetof(struct lys_node_list, keys_size),
                 sizeof(((struct lys_node_list *)0)->keys_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "keys", offsetof(struct lys_node_list, keys),
            sizeof(((struct lys_node_list *)0)->keys),
            _CFFI_OP(_CFFI_OP_NOOP, 255) },
  { "min", offsetof(struct lys_node_list, min),
           sizeof(((struct lys_node_list *)0)->min),
           _CFFI_OP(_CFFI_OP_NOOP, 282) },
  { "max", offsetof(struct lys_node_list, max),
           sizeof(((struct lys_node_list *)0)->max),
           _CFFI_OP(_CFFI_OP_NOOP, 282) },
  { "expr", offsetof(struct lys_restr, expr),
            sizeof(((struct lys_restr *)0)->expr),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "date", offsetof(struct lys_revision, date),
            sizeof(((struct lys_revision *)0)->date),
            _CFFI_OP(_CFFI_OP_NOOP, 226) },
  { "ext_size", offsetof(struct lys_revision, ext_size),
                sizeof(((struct lys_revision *)0)->ext_size),
                _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "ext", offsetof(struct lys_revision, ext),
           sizeof(((struct lys_revision *)0)->ext),
           _CFFI_OP(_CFFI_OP_NOOP, 241) },
  { "dsc", offsetof(struct lys_revision, dsc),
           sizeof(((struct lys_revision *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "ref", offsetof(struct lys_revision, ref),
           sizeof(((struct lys_revision *)0)->ref),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "name", offsetof(struct lys_tpdf, name),
            sizeof(((struct lys_tpdf *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dsc", offsetof(struct lys_tpdf, dsc),
           sizeof(((struct lys_tpdf *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "ext_size", offsetof(struct lys_tpdf, ext_size),
                sizeof(((struct lys_tpdf *)0)->ext_size),
                _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "ext", offsetof(struct lys_tpdf, ext),
           sizeof(((struct lys_tpdf *)0)->ext),
           _CFFI_OP(_CFFI_OP_NOOP, 241) },
  { "units", offsetof(struct lys_tpdf, units),
             sizeof(((struct lys_tpdf *)0)->units),
             _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "type", offsetof(struct lys_tpdf, type),
            sizeof(((struct lys_tpdf *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 268) },
  { "module", offsetof(struct lys_tpdf, module),
              sizeof(((struct lys_tpdf *)0)->module),
              _CFFI_OP(_CFFI_OP_NOOP, 249) },
  { "dflt", offsetof(struct lys_tpdf, dflt),
            sizeof(((struct lys_tpdf *)0)->dflt),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "base", offsetof(struct lys_type, base),
            sizeof(((struct lys_type *)0)->base),
            _CFFI_OP(_CFFI_OP_NOOP, 221) },
  { "value_flags", offsetof(struct lys_type, value_flags),
                   sizeof(((struct lys_type *)0)->value_flags),
                   _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "ext_size", offsetof(struct lys_type, ext_size),
                sizeof(((struct lys_type *)0)->ext_size),
                _CFFI_OP(_CFFI_OP_NOOP, 283) },
  { "ext", offsetof(struct lys_type, ext),
           sizeof(((struct lys_type *)0)->ext),
           _CFFI_OP(_CFFI_OP_NOOP, 241) },
  { "der", offsetof(struct lys_type, der),
           sizeof(((struct lys_type *)0)->der),
           _CFFI_OP(_CFFI_OP_NOOP, 265) },
  { "parent", offsetof(struct lys_type, parent),
              sizeof(((struct lys_type *)0)->parent),
              _CFFI_OP(_CFFI_OP_NOOP, 265) },
  { "info", offsetof(struct lys_type, info),
            sizeof(((struct lys_type *)0)->info),
            _CFFI_OP(_CFFI_OP_NOOP, 285) },
  { "name", offsetof(struct lys_type_bit, name),
            sizeof(((struct lys_type_bit *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dsc", offsetof(struct lys_type_bit, dsc),
           sizeof(((struct lys_type_bit *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "pos", offsetof(struct lys_type_bit, pos),
           sizeof(((struct lys_type_bit *)0)->pos),
           _CFFI_OP(_CFFI_OP_NOOP, 282) },
  { "name", offsetof(struct lys_type_enum, name),
            sizeof(((struct lys_type_enum *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "dsc", offsetof(struct lys_type_enum, dsc),
           sizeof(((struct lys_type_enum *)0)->dsc),
           _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "length", offsetof(struct lys_type_info_binary, length),
              sizeof(((struct lys_type_info_binary *)0)->length),
              _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "bit", offsetof(struct lys_type_info_bits, bit),
           sizeof(((struct lys_type_info_bits *)0)->bit),
           _CFFI_OP(_CFFI_OP_NOOP, 269) },
  { "count", offsetof(struct lys_type_info_bits, count),
             sizeof(((struct lys_type_info_bits *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 286) },
  { "range", offsetof(struct lys_type_info_dec64, range),
             sizeof(((struct lys_type_info_dec64 *)0)->range),
             _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "enm", offsetof(struct lys_type_info_enums, enm),
           sizeof(((struct lys_type_info_enums *)0)->enm),
           _CFFI_OP(_CFFI_OP_NOOP, 271) },
  { "count", offsetof(struct lys_type_info_enums, count),
             sizeof(((struct lys_type_info_enums *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 286) },
  { "path", offsetof(struct lys_type_info_lref, path),
            sizeof(((struct lys_type_info_lref *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 16) },
  { "target", offsetof(struct lys_type_info_lref, target),
              sizeof(((struct lys_type_info_lref *)0)->target),
              _CFFI_OP(_CFFI_OP_NOOP, 256) },
  { "req", offsetof(struct lys_type_info_lref, req),
           sizeof(((struct lys_type_info_lref *)0)->req),
           _CFFI_OP(_CFFI_OP_NOOP, 229) },
  { "range", offsetof(struct lys_type_info_num, range),
             sizeof(((struct lys_type_info_num *)0)->range),
             _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "length", offsetof(struct lys_type_info_str, length),
              sizeof(((struct lys_type_info_str *)0)->length),
              _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "patterns", offsetof(struct lys_type_info_str, patterns),
                sizeof(((struct lys_type_info_str *)0)->patterns),
                _CFFI_OP(_CFFI_OP_NOOP, 261) },
  { "pat_count", offsetof(struct lys_type_info_str, pat_count),
                 sizeof(((struct lys_type_info_str *)0)->pat_count),
                 _CFFI_OP(_CFFI_OP_NOOP, 286) },
  { "types", offsetof(struct lys_type_info_union, types),
             sizeof(((struct lys_type_info_union *)0)->types),
             _CFFI_OP(_CFFI_OP_NOOP, 267) },
  { "count", offsetof(struct lys_type_info_union, count),
             sizeof(((struct lys_type_info_union *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 286) },
  { "has_ptr_type", offsetof(struct lys_type_info_union, has_ptr_type),
                    sizeof(((struct lys_type_info_union *)0)->has_ptr_type),
                    _CFFI_OP(_CFFI_OP_NOOP, 20) },
  { "s", offsetof(union ly_set_set, s),
         sizeof(((union ly_set_set *)0)->s),
         _CFFI_OP(_CFFI_OP_NOOP, 251) },
  { "d", offsetof(union ly_set_set, d),
         sizeof(((union ly_set_set *)0)->d),
         _CFFI_OP(_CFFI_OP_NOOP, 61) },
  { "bln", offsetof(lyd_val, bln),
           sizeof(((lyd_val *)0)->bln),
           _CFFI_OP(_CFFI_OP_NOOP, 229) },
  { "leafref", offsetof(lyd_val, leafref),
               sizeof(((lyd_val *)0)->leafref),
               _CFFI_OP(_CFFI_OP_NOOP, 66) },
  { "binary", offsetof(union lys_type_info, binary),
              sizeof(((union lys_type_info *)0)->binary),
              _CFFI_OP(_CFFI_OP_NOOP, 273) },
  { "bits", offsetof(union lys_type_info, bits),
            sizeof(((union lys_type_info *)0)->bits),
            _CFFI_OP(_CFFI_OP_NOOP, 274) },
  { "dec64", offsetof(union lys_type_info, dec64),
             sizeof(((union lys_type_info *)0)->dec64),
             _CFFI_OP(_CFFI_OP_NOOP, 275) },
  { "enums", offsetof(union lys_type_info, enums),
             sizeof(((union lys_type_info *)0)->enums),
             _CFFI_OP(_CFFI_OP_NOOP, 276) },
  { "num", offsetof(union lys_type_info, num),
           sizeof(((union lys_type_info *)0)->num),
           _CFFI_OP(_CFFI_OP_NOOP, 278) },
  { "lref", offsetof(union lys_type_info, lref),
            sizeof(((union lys_type_info *)0)->lref),
            _CFFI_OP(_CFFI_OP_NOOP, 277) },
  { "str", offsetof(union lys_type_info, str),
           sizeof(((union lys_type_info *)0)->str),
           _CFFI_OP(_CFFI_OP_NOOP, 279) },
  { "uni", offsetof(union lys_type_info, uni),
           sizeof(((union lys_type_info *)0)->uni),
           _CFFI_OP(_CFFI_OP_NOOP, 280) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "ly_ctx", 231, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "ly_err_item", 232, 0,
    sizeof(struct ly_err_item), offsetof(struct _cffi_align_struct_ly_err_item, y), 0, 4 },
  { "ly_set", 233, _CFFI_F_CHECK_FIELDS,
    sizeof(struct ly_set), offsetof(struct _cffi_align_struct_ly_set, y), 4, 3 },
  { "ly_set_set", 284, _CFFI_F_UNION,
    sizeof(union ly_set_set), offsetof(struct _cffi_align_union_ly_set_set, y), 113, 2 },
  { "lyd_difflist", 234, 0,
    sizeof(struct lyd_difflist), offsetof(struct _cffi_align_struct_lyd_difflist, y), 7, 3 },
  { "lyd_node", 237, 0,
    sizeof(struct lyd_node), offsetof(struct _cffi_align_struct_lyd_node, y), 10, 4 },
  { "lyd_node_leaf_list", 238, 0,
    sizeof(struct lyd_node_leaf_list), offsetof(struct _cffi_align_struct_lyd_node_leaf_list, y), 14, 6 },
  { "lyd_value_u", 230, _CFFI_F_UNION,
    sizeof(lyd_val), offsetof(struct _cffi_align__lyd_val, y), 115, 2 },
  { "lys_ext", 240, 0,
    sizeof(struct lys_ext), offsetof(struct _cffi_align_struct_lys_ext, y), 20, 2 },
  { "lys_ext_instance", 243, 0,
    sizeof(struct lys_ext_instance), offsetof(struct _cffi_align_struct_lys_ext_instance, y), 22, 2 },
  { "lys_feature", 246, 0,
    sizeof(struct lys_feature), offsetof(struct _cffi_align_struct_lys_feature, y), 24, 7 },
  { "lys_iffeature", 248, 0,
    sizeof(struct lys_iffeature), offsetof(struct _cffi_align_struct_lys_iffeature, y), 31, 2 },
  { "lys_module", 250, 0,
    sizeof(struct lys_module), offsetof(struct _cffi_align_struct_lys_module, y), 33, 8 },
  { "lys_node", 253, 0,
    sizeof(struct lys_node), offsetof(struct _cffi_align_struct_lys_node, y), 41, 8 },
  { "lys_node_container", 254, 0,
    sizeof(struct lys_node_container), offsetof(struct _cffi_align_struct_lys_node_container, y), 49, 3 },
  { "lys_node_leaf", 257, 0,
    sizeof(struct lys_node_leaf), offsetof(struct _cffi_align_struct_lys_node_leaf, y), 52, 5 },
  { "lys_node_leaflist", 258, 0,
    sizeof(struct lys_node_leaflist), offsetof(struct _cffi_align_struct_lys_node_leaflist, y), 57, 8 },
  { "lys_node_list", 260, 0,
    sizeof(struct lys_node_list), offsetof(struct _cffi_align_struct_lys_node_list, y), 65, 6 },
  { "lys_restr", 262, 0,
    sizeof(struct lys_restr), offsetof(struct _cffi_align_struct_lys_restr, y), 71, 1 },
  { "lys_revision", 264, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_revision), offsetof(struct _cffi_align_struct_lys_revision, y), 72, 5 },
  { "lys_tpdf", 266, 0,
    sizeof(struct lys_tpdf), offsetof(struct _cffi_align_struct_lys_tpdf, y), 77, 8 },
  { "lys_type", 268, 0,
    sizeof(struct lys_type), offsetof(struct _cffi_align_struct_lys_type, y), 85, 7 },
  { "lys_type_bit", 270, 0,
    sizeof(struct lys_type_bit), offsetof(struct _cffi_align_struct_lys_type_bit, y), 92, 3 },
  { "lys_type_enum", 272, 0,
    sizeof(struct lys_type_enum), offsetof(struct _cffi_align_struct_lys_type_enum, y), 95, 2 },
  { "lys_type_info", 285, _CFFI_F_UNION,
    sizeof(union lys_type_info), offsetof(struct _cffi_align_union_lys_type_info, y), 117, 8 },
  { "lys_type_info_binary", 273, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_type_info_binary), offsetof(struct _cffi_align_struct_lys_type_info_binary, y), 97, 1 },
  { "lys_type_info_bits", 274, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_type_info_bits), offsetof(struct _cffi_align_struct_lys_type_info_bits, y), 98, 2 },
  { "lys_type_info_dec64", 275, 0,
    sizeof(struct lys_type_info_dec64), offsetof(struct _cffi_align_struct_lys_type_info_dec64, y), 100, 1 },
  { "lys_type_info_enums", 276, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_type_info_enums), offsetof(struct _cffi_align_struct_lys_type_info_enums, y), 101, 2 },
  { "lys_type_info_lref", 277, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_type_info_lref), offsetof(struct _cffi_align_struct_lys_type_info_lref, y), 103, 3 },
  { "lys_type_info_num", 278, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_type_info_num), offsetof(struct _cffi_align_struct_lys_type_info_num, y), 106, 1 },
  { "lys_type_info_str", 279, 0,
    sizeof(struct lys_type_info_str), offsetof(struct _cffi_align_struct_lys_type_info_str, y), 107, 3 },
  { "lys_type_info_union", 280, _CFFI_F_CHECK_FIELDS,
    sizeof(struct lys_type_info_union), offsetof(struct _cffi_align_struct_lys_type_info_union, y), 110, 3 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$LYD_ANYDATA_VALUETYPE", 122, _cffi_prim_int(sizeof(LYD_ANYDATA_VALUETYPE), ((LYD_ANYDATA_VALUETYPE)-1) <= 0),
    "" },
  { "$LYD_DIFFTYPE", 219, _cffi_prim_int(sizeof(LYD_DIFFTYPE), ((LYD_DIFFTYPE)-1) <= 0),
    "LYD_DIFF_END,LYD_DIFF_DELETED,LYD_DIFF_CHANGED,LYD_DIFF_MOVEDAFTER1,LYD_DIFF_CREATED,LYD_DIFF_MOVEDAFTER2" },
  { "$LYD_FORMAT", 28, _cffi_prim_int(sizeof(LYD_FORMAT), ((LYD_FORMAT)-1) <= 0),
    "LYD_XML,LYD_JSON,LYD_LYB" },
  { "$LYS_INFORMAT", 148, _cffi_prim_int(sizeof(LYS_INFORMAT), ((LYS_INFORMAT)-1) <= 0),
    "LYS_IN_UNKNOWN,LYS_IN_YANG,LYS_IN_YIN" },
  { "$LYS_OUTFORMAT", 34, _cffi_prim_int(sizeof(LYS_OUTFORMAT), ((LYS_OUTFORMAT)-1) <= 0),
    "LYS_OUT_UNKNOWN,LYS_OUT_YANG,LYS_OUT_YIN,LYS_OUT_TREE,LYS_OUT_INFO,LYS_OUT_JSON" },
  { "$LY_DATA_TYPE", 221, _cffi_prim_int(sizeof(LY_DATA_TYPE), ((LY_DATA_TYPE)-1) <= 0),
    "LY_TYPE_DER,LY_TYPE_BINARY,LY_TYPE_BITS,LY_TYPE_BOOL,LY_TYPE_DEC64,LY_TYPE_EMPTY,LY_TYPE_ENUM,LY_TYPE_IDENT,LY_TYPE_INST,LY_TYPE_LEAFREF,LY_TYPE_STRING,LY_TYPE_UNION,LY_TYPE_INT8,LY_TYPE_UINT8,LY_TYPE_INT16,LY_TYPE_UINT16,LY_TYPE_INT32,LY_TYPE_UINT32,LY_TYPE_INT64,LY_TYPE_UINT64,LY_TYPE_UNKNOWN" },
  { "$LY_ERR", 187, _cffi_prim_int(sizeof(LY_ERR), ((LY_ERR)-1) <= 0),
    "LY_SUCCESS" },
  { "$LY_LOG_LEVEL", 3, _cffi_prim_int(sizeof(LY_LOG_LEVEL), ((LY_LOG_LEVEL)-1) <= 0),
    "LY_LLERR,LY_LLWRN,LY_LLVRB,LY_LLDBG" },
  { "$LY_VECODE", 222, _cffi_prim_int(sizeof(LY_VECODE), ((LY_VECODE)-1) <= 0),
    "LYVE_SUCCESS,LYVE_PATH_EXISTS" },
  { "lys_nodetype", 220, _cffi_prim_int(sizeof(LYS_NODE), ((LYS_NODE)-1) <= 0),
    "LYS_UNKNOWN,LYS_CONTAINER,LYS_CHOICE,LYS_LEAF,LYS_LEAFLIST,LYS_LIST,LYS_ANYXML,LYS_CASE,LYS_NOTIF,LYS_RPC,LYS_INPUT,LYS_OUTPUT,LYS_GROUPING,LYS_USES,LYS_AUGMENT,LYS_ACTION,LYS_ANYDATA,LYS_EXT" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "LYD_ANYDATA_VALUETYPE", 122 },
  { "LYD_DIFFTYPE", 219 },
  { "LYD_FORMAT", 28 },
  { "LYS_INFORMAT", 148 },
  { "LYS_NODE", 220 },
  { "LYS_OUTFORMAT", 34 },
  { "LY_DATA_TYPE", 221 },
  { "LY_ERR", 187 },
  { "LY_LOG_LEVEL", 3 },
  { "LY_VECODE", 222 },
  { "lyd_val", 230 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  175,  /* num_globals */
  33,  /* num_struct_unions */
  10,  /* num_enums */
  11,  /* num_typenames */
  NULL,  /* no includes */
  288,  /* num_types */
  1,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__libyang(const void *p[])
{
    if (((intptr_t)p[0]) >= 0x0A03) {
        _cffi_call_python_org = (void(*)(struct _cffi_externpy_s *, char *))p[1];
    }
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__libyang(void) { return NULL; }
#  else
     init_libyang(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__libyang(void)
{
  return _cffi_init("_libyang", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_libyang(void)
{
  _cffi_init("_libyang", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
